# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _trellis_swig3
else:
    import _trellis_swig3

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)



def high_res_timer_now() -> "gr::high_res_timer_type":
    r"""high_res_timer_now() -> gr::high_res_timer_type"""
    return _trellis_swig3.high_res_timer_now()

def high_res_timer_now_perfmon() -> "gr::high_res_timer_type":
    r"""high_res_timer_now_perfmon() -> gr::high_res_timer_type"""
    return _trellis_swig3.high_res_timer_now_perfmon()

def high_res_timer_tps() -> "gr::high_res_timer_type":
    r"""high_res_timer_tps() -> gr::high_res_timer_type"""
    return _trellis_swig3.high_res_timer_tps()

def high_res_timer_epoch() -> "gr::high_res_timer_type":
    r"""high_res_timer_epoch() -> gr::high_res_timer_type"""
    return _trellis_swig3.high_res_timer_epoch()
TRELLIS_EUCLIDEAN = _trellis_swig3.TRELLIS_EUCLIDEAN

TRELLIS_HARD_SYMBOL = _trellis_swig3.TRELLIS_HARD_SYMBOL

TRELLIS_HARD_BIT = _trellis_swig3.TRELLIS_HARD_BIT

TRELLIS_MIN_SUM = _trellis_swig3.TRELLIS_MIN_SUM

TRELLIS_SUM_PRODUCT = _trellis_swig3.TRELLIS_SUM_PRODUCT

class fsm(object):
    r"""Proxy of C++ gr::trellis::fsm class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(fsm self) -> fsm
        __init__(fsm self, fsm FSM) -> fsm
        __init__(fsm self, int I, int S, int O, std::vector< int,std::allocator< int > > const & NS, std::vector< int,std::allocator< int > > const & OS) -> fsm
        __init__(fsm self, char const * name) -> fsm
        __init__(fsm self, int k, int n, std::vector< int,std::allocator< int > > const & G) -> fsm
        __init__(fsm self, int mod_size, int ch_length) -> fsm
        __init__(fsm self, int P, int M, int L) -> fsm
        __init__(fsm self, fsm FSM1, fsm FSM2) -> fsm
        __init__(fsm self, fsm FSMo, fsm FSMi, bool serial) -> fsm
        __init__(fsm self, fsm FSM, int n) -> fsm
        """
        _trellis_swig3.fsm_swiginit(self, _trellis_swig3.new_fsm(*args))

    def I(self) -> "int":
        r"""I(fsm self) -> int"""
        return _trellis_swig3.fsm_I(self)

    def S(self) -> "int":
        r"""S(fsm self) -> int"""
        return _trellis_swig3.fsm_S(self)

    def O(self) -> "int":
        r"""O(fsm self) -> int"""
        return _trellis_swig3.fsm_O(self)

    def NS(self) -> "std::vector< int,std::allocator< int > > const &":
        r"""NS(fsm self) -> std::vector< int,std::allocator< int > > const &"""
        return _trellis_swig3.fsm_NS(self)

    def OS(self) -> "std::vector< int,std::allocator< int > > const &":
        r"""OS(fsm self) -> std::vector< int,std::allocator< int > > const &"""
        return _trellis_swig3.fsm_OS(self)

    def PS(self) -> "std::vector< std::vector< int,std::allocator< int > >,std::allocator< std::vector< int,std::allocator< int > > > > const &":
        r"""PS(fsm self) -> std::vector< std::vector< int,std::allocator< int > >,std::allocator< std::vector< int,std::allocator< int > > > > const &"""
        return _trellis_swig3.fsm_PS(self)

    def PI(self) -> "std::vector< std::vector< int,std::allocator< int > >,std::allocator< std::vector< int,std::allocator< int > > > > const &":
        r"""PI(fsm self) -> std::vector< std::vector< int,std::allocator< int > >,std::allocator< std::vector< int,std::allocator< int > > > > const &"""
        return _trellis_swig3.fsm_PI(self)

    def TMi(self) -> "std::vector< int,std::allocator< int > > const &":
        r"""TMi(fsm self) -> std::vector< int,std::allocator< int > > const &"""
        return _trellis_swig3.fsm_TMi(self)

    def TMl(self) -> "std::vector< int,std::allocator< int > > const &":
        r"""TMl(fsm self) -> std::vector< int,std::allocator< int > > const &"""
        return _trellis_swig3.fsm_TMl(self)

    def write_trellis_svg(self, filename: "std::string", number_stages: "int") -> "void":
        r"""write_trellis_svg(fsm self, std::string filename, int number_stages)"""
        return _trellis_swig3.fsm_write_trellis_svg(self, filename, number_stages)

    def write_fsm_txt(self, filename: "std::string") -> "void":
        r"""write_fsm_txt(fsm self, std::string filename)"""
        return _trellis_swig3.fsm_write_fsm_txt(self, filename)
    __swig_destroy__ = _trellis_swig3.delete_fsm

# Register fsm in _trellis_swig3:
_trellis_swig3.fsm_swigregister(fsm)

class interleaver(object):
    r"""Proxy of C++ gr::trellis::interleaver class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(interleaver self) -> interleaver
        __init__(interleaver self, interleaver INTERLEAVER) -> interleaver
        __init__(interleaver self, unsigned int K, std::vector< int,std::allocator< int > > const & INTER) -> interleaver
        __init__(interleaver self, char const * name) -> interleaver
        __init__(interleaver self, unsigned int K, int seed) -> interleaver
        """
        _trellis_swig3.interleaver_swiginit(self, _trellis_swig3.new_interleaver(*args))

    def K(self) -> "unsigned int":
        r"""K(interleaver self) -> unsigned int"""
        return _trellis_swig3.interleaver_K(self)

    def INTER(self) -> "std::vector< int,std::allocator< int > > const &":
        r"""INTER(interleaver self) -> std::vector< int,std::allocator< int > > const &"""
        return _trellis_swig3.interleaver_INTER(self)

    def DEINTER(self) -> "std::vector< int,std::allocator< int > > const &":
        r"""DEINTER(interleaver self) -> std::vector< int,std::allocator< int > > const &"""
        return _trellis_swig3.interleaver_DEINTER(self)

    def write_interleaver_txt(self, filename: "std::string") -> "void":
        r"""write_interleaver_txt(interleaver self, std::string filename)"""
        return _trellis_swig3.interleaver_write_interleaver_txt(self, filename)
    __swig_destroy__ = _trellis_swig3.delete_interleaver

# Register interleaver in _trellis_swig3:
_trellis_swig3.interleaver_swigregister(interleaver)

class sccc_decoder_b(object):
    r"""Proxy of C++ gr::trellis::sccc_decoder_blk< std::uint8_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t") -> "gr::trellis::sccc_decoder_blk< unsigned char >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE) -> sccc_decoder_b_sptr"""
        return _trellis_swig3.sccc_decoder_b_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_b self) -> fsm"""
        return _trellis_swig3.sccc_decoder_b_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_b self) -> fsm"""
        return _trellis_swig3.sccc_decoder_b_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_b self) -> int"""
        return _trellis_swig3.sccc_decoder_b_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_b self) -> int"""
        return _trellis_swig3.sccc_decoder_b_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_b self) -> int"""
        return _trellis_swig3.sccc_decoder_b_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_b self) -> int"""
        return _trellis_swig3.sccc_decoder_b_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_b self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_b_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_b self) -> int"""
        return _trellis_swig3.sccc_decoder_b_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_b self) -> int"""
        return _trellis_swig3.sccc_decoder_b_repetitions(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_b self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_b_SISO_TYPE(self)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_b

# Register sccc_decoder_b in _trellis_swig3:
_trellis_swig3.sccc_decoder_b_swigregister(sccc_decoder_b)

def sccc_decoder_b_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t") -> "gr::trellis::sccc_decoder_blk< unsigned char >::sptr":
    r"""sccc_decoder_b_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE) -> sccc_decoder_b_sptr"""
    return _trellis_swig3.sccc_decoder_b_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE)

class sccc_decoder_b_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::sccc_decoder_blk< std::uint8_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(sccc_decoder_b_sptr self) -> sccc_decoder_b_sptr
        __init__(sccc_decoder_b_sptr self, sccc_decoder_b p) -> sccc_decoder_b_sptr
        """
        _trellis_swig3.sccc_decoder_b_sptr_swiginit(self, _trellis_swig3.new_sccc_decoder_b_sptr(*args))

    def __deref__(self) -> "gr::trellis::sccc_decoder_blk< std::uint8_t > *":
        r"""__deref__(sccc_decoder_b_sptr self) -> sccc_decoder_b"""
        return _trellis_swig3.sccc_decoder_b_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_b_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t") -> "gr::trellis::sccc_decoder_blk< unsigned char >::sptr":
        r"""make(sccc_decoder_b_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE) -> sccc_decoder_b_sptr"""
        return _trellis_swig3.sccc_decoder_b_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_b_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_b_sptr_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_b_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_b_sptr_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_b_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_b_sptr_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_b_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_b_sptr_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_b_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_b_sptr_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_b_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_b_sptr_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_b_sptr self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_b_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_b_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_b_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_b_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_b_sptr_repetitions(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_b_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_b_sptr_SISO_TYPE(self)

    def history(self) -> "unsigned int":
        r"""history(sccc_decoder_b_sptr self) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_b_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(sccc_decoder_b_sptr self, int which, int delay)
        declare_sample_delay(sccc_decoder_b_sptr self, unsigned int delay)
        """
        return _trellis_swig3.sccc_decoder_b_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(sccc_decoder_b_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_b_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(sccc_decoder_b_sptr self, int multiple)"""
        return _trellis_swig3.sccc_decoder_b_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(sccc_decoder_b_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_b_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(sccc_decoder_b_sptr self) -> double"""
        return _trellis_swig3.sccc_decoder_b_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(sccc_decoder_b_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_b_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(sccc_decoder_b_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_b_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(sccc_decoder_b_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_b_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(sccc_decoder_b_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_b_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(sccc_decoder_b_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_b_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(sccc_decoder_b_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_b_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(sccc_decoder_b_sptr self, std::string level)"""
        return _trellis_swig3.sccc_decoder_b_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(sccc_decoder_b_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_b_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(sccc_decoder_b_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_b_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(sccc_decoder_b_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_b_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(sccc_decoder_b_sptr self)"""
        return _trellis_swig3.sccc_decoder_b_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(sccc_decoder_b_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_b_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(sccc_decoder_b_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_b_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(sccc_decoder_b_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_b_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(sccc_decoder_b_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_b_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(sccc_decoder_b_sptr self, long max_output_buffer)
        set_max_output_buffer(sccc_decoder_b_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_b_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(sccc_decoder_b_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_b_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(sccc_decoder_b_sptr self, long min_output_buffer)
        set_min_output_buffer(sccc_decoder_b_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_b_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(sccc_decoder_b_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_b_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(sccc_decoder_b_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_b_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(sccc_decoder_b_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_b_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(sccc_decoder_b_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_b_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(sccc_decoder_b_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_b_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(sccc_decoder_b_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_b_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(sccc_decoder_b_sptr self, int which) -> float
        pc_input_buffers_full(sccc_decoder_b_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_b_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(sccc_decoder_b_sptr self, int which) -> float
        pc_input_buffers_full_avg(sccc_decoder_b_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_b_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(sccc_decoder_b_sptr self, int which) -> float
        pc_input_buffers_full_var(sccc_decoder_b_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_b_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(sccc_decoder_b_sptr self, int which) -> float
        pc_output_buffers_full(sccc_decoder_b_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_b_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(sccc_decoder_b_sptr self, int which) -> float
        pc_output_buffers_full_avg(sccc_decoder_b_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_b_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(sccc_decoder_b_sptr self, int which) -> float
        pc_output_buffers_full_var(sccc_decoder_b_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_b_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(sccc_decoder_b_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_b_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(sccc_decoder_b_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_b_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(sccc_decoder_b_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_b_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(sccc_decoder_b_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_b_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(sccc_decoder_b_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_b_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(sccc_decoder_b_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.sccc_decoder_b_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(sccc_decoder_b_sptr self)"""
        return _trellis_swig3.sccc_decoder_b_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(sccc_decoder_b_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.sccc_decoder_b_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(sccc_decoder_b_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_b_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(sccc_decoder_b_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_b_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(sccc_decoder_b_sptr self, int priority) -> int"""
        return _trellis_swig3.sccc_decoder_b_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(sccc_decoder_b_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_b_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(sccc_decoder_b_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_b_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(sccc_decoder_b_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_b_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(sccc_decoder_b_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_b_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(sccc_decoder_b_sptr self) -> long"""
        return _trellis_swig3.sccc_decoder_b_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(sccc_decoder_b_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.sccc_decoder_b_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(sccc_decoder_b_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.sccc_decoder_b_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(sccc_decoder_b_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_b_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(sccc_decoder_b_sptr self, std::string name)"""
        return _trellis_swig3.sccc_decoder_b_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(sccc_decoder_b_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.sccc_decoder_b_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(sccc_decoder_b_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_b_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(sccc_decoder_b_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_b_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(sccc_decoder_b_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_b_sptr_message_subscribers(self, which_port)

# Register sccc_decoder_b_sptr in _trellis_swig3:
_trellis_swig3.sccc_decoder_b_sptr_swigregister(sccc_decoder_b_sptr)


sccc_decoder_b_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
sccc_decoder_b = sccc_decoder_b.make

class sccc_decoder_s(object):
    r"""Proxy of C++ gr::trellis::sccc_decoder_blk< std::int16_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t") -> "gr::trellis::sccc_decoder_blk< short >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE) -> sccc_decoder_s_sptr"""
        return _trellis_swig3.sccc_decoder_s_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_s self) -> fsm"""
        return _trellis_swig3.sccc_decoder_s_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_s self) -> fsm"""
        return _trellis_swig3.sccc_decoder_s_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_s self) -> int"""
        return _trellis_swig3.sccc_decoder_s_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_s self) -> int"""
        return _trellis_swig3.sccc_decoder_s_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_s self) -> int"""
        return _trellis_swig3.sccc_decoder_s_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_s self) -> int"""
        return _trellis_swig3.sccc_decoder_s_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_s self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_s_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_s self) -> int"""
        return _trellis_swig3.sccc_decoder_s_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_s self) -> int"""
        return _trellis_swig3.sccc_decoder_s_repetitions(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_s self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_s_SISO_TYPE(self)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_s

# Register sccc_decoder_s in _trellis_swig3:
_trellis_swig3.sccc_decoder_s_swigregister(sccc_decoder_s)

def sccc_decoder_s_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t") -> "gr::trellis::sccc_decoder_blk< short >::sptr":
    r"""sccc_decoder_s_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE) -> sccc_decoder_s_sptr"""
    return _trellis_swig3.sccc_decoder_s_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE)

class sccc_decoder_s_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::sccc_decoder_blk< std::int16_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(sccc_decoder_s_sptr self) -> sccc_decoder_s_sptr
        __init__(sccc_decoder_s_sptr self, sccc_decoder_s p) -> sccc_decoder_s_sptr
        """
        _trellis_swig3.sccc_decoder_s_sptr_swiginit(self, _trellis_swig3.new_sccc_decoder_s_sptr(*args))

    def __deref__(self) -> "gr::trellis::sccc_decoder_blk< std::int16_t > *":
        r"""__deref__(sccc_decoder_s_sptr self) -> sccc_decoder_s"""
        return _trellis_swig3.sccc_decoder_s_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_s_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t") -> "gr::trellis::sccc_decoder_blk< short >::sptr":
        r"""make(sccc_decoder_s_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE) -> sccc_decoder_s_sptr"""
        return _trellis_swig3.sccc_decoder_s_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_s_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_s_sptr_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_s_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_s_sptr_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_s_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_s_sptr_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_s_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_s_sptr_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_s_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_s_sptr_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_s_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_s_sptr_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_s_sptr self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_s_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_s_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_s_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_s_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_s_sptr_repetitions(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_s_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_s_sptr_SISO_TYPE(self)

    def history(self) -> "unsigned int":
        r"""history(sccc_decoder_s_sptr self) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_s_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(sccc_decoder_s_sptr self, int which, int delay)
        declare_sample_delay(sccc_decoder_s_sptr self, unsigned int delay)
        """
        return _trellis_swig3.sccc_decoder_s_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(sccc_decoder_s_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_s_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(sccc_decoder_s_sptr self, int multiple)"""
        return _trellis_swig3.sccc_decoder_s_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(sccc_decoder_s_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_s_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(sccc_decoder_s_sptr self) -> double"""
        return _trellis_swig3.sccc_decoder_s_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(sccc_decoder_s_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_s_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(sccc_decoder_s_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_s_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(sccc_decoder_s_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_s_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(sccc_decoder_s_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_s_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(sccc_decoder_s_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_s_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(sccc_decoder_s_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_s_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(sccc_decoder_s_sptr self, std::string level)"""
        return _trellis_swig3.sccc_decoder_s_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(sccc_decoder_s_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_s_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(sccc_decoder_s_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_s_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(sccc_decoder_s_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_s_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(sccc_decoder_s_sptr self)"""
        return _trellis_swig3.sccc_decoder_s_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(sccc_decoder_s_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_s_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(sccc_decoder_s_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_s_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(sccc_decoder_s_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_s_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(sccc_decoder_s_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_s_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(sccc_decoder_s_sptr self, long max_output_buffer)
        set_max_output_buffer(sccc_decoder_s_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_s_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(sccc_decoder_s_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_s_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(sccc_decoder_s_sptr self, long min_output_buffer)
        set_min_output_buffer(sccc_decoder_s_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_s_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(sccc_decoder_s_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_s_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(sccc_decoder_s_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_s_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(sccc_decoder_s_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_s_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(sccc_decoder_s_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_s_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(sccc_decoder_s_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_s_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(sccc_decoder_s_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_s_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(sccc_decoder_s_sptr self, int which) -> float
        pc_input_buffers_full(sccc_decoder_s_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_s_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(sccc_decoder_s_sptr self, int which) -> float
        pc_input_buffers_full_avg(sccc_decoder_s_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_s_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(sccc_decoder_s_sptr self, int which) -> float
        pc_input_buffers_full_var(sccc_decoder_s_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_s_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(sccc_decoder_s_sptr self, int which) -> float
        pc_output_buffers_full(sccc_decoder_s_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_s_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(sccc_decoder_s_sptr self, int which) -> float
        pc_output_buffers_full_avg(sccc_decoder_s_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_s_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(sccc_decoder_s_sptr self, int which) -> float
        pc_output_buffers_full_var(sccc_decoder_s_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_s_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(sccc_decoder_s_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_s_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(sccc_decoder_s_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_s_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(sccc_decoder_s_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_s_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(sccc_decoder_s_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_s_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(sccc_decoder_s_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_s_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(sccc_decoder_s_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.sccc_decoder_s_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(sccc_decoder_s_sptr self)"""
        return _trellis_swig3.sccc_decoder_s_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(sccc_decoder_s_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.sccc_decoder_s_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(sccc_decoder_s_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_s_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(sccc_decoder_s_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_s_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(sccc_decoder_s_sptr self, int priority) -> int"""
        return _trellis_swig3.sccc_decoder_s_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(sccc_decoder_s_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_s_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(sccc_decoder_s_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_s_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(sccc_decoder_s_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_s_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(sccc_decoder_s_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_s_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(sccc_decoder_s_sptr self) -> long"""
        return _trellis_swig3.sccc_decoder_s_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(sccc_decoder_s_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.sccc_decoder_s_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(sccc_decoder_s_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.sccc_decoder_s_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(sccc_decoder_s_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_s_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(sccc_decoder_s_sptr self, std::string name)"""
        return _trellis_swig3.sccc_decoder_s_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(sccc_decoder_s_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.sccc_decoder_s_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(sccc_decoder_s_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_s_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(sccc_decoder_s_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_s_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(sccc_decoder_s_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_s_sptr_message_subscribers(self, which_port)

# Register sccc_decoder_s_sptr in _trellis_swig3:
_trellis_swig3.sccc_decoder_s_sptr_swigregister(sccc_decoder_s_sptr)


sccc_decoder_s_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
sccc_decoder_s = sccc_decoder_s.make

class sccc_decoder_i(object):
    r"""Proxy of C++ gr::trellis::sccc_decoder_blk< std::int32_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t") -> "gr::trellis::sccc_decoder_blk< int >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE) -> sccc_decoder_i_sptr"""
        return _trellis_swig3.sccc_decoder_i_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_i self) -> fsm"""
        return _trellis_swig3.sccc_decoder_i_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_i self) -> fsm"""
        return _trellis_swig3.sccc_decoder_i_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_i self) -> int"""
        return _trellis_swig3.sccc_decoder_i_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_i self) -> int"""
        return _trellis_swig3.sccc_decoder_i_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_i self) -> int"""
        return _trellis_swig3.sccc_decoder_i_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_i self) -> int"""
        return _trellis_swig3.sccc_decoder_i_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_i self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_i_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_i self) -> int"""
        return _trellis_swig3.sccc_decoder_i_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_i self) -> int"""
        return _trellis_swig3.sccc_decoder_i_repetitions(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_i self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_i_SISO_TYPE(self)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_i

# Register sccc_decoder_i in _trellis_swig3:
_trellis_swig3.sccc_decoder_i_swigregister(sccc_decoder_i)

def sccc_decoder_i_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t") -> "gr::trellis::sccc_decoder_blk< int >::sptr":
    r"""sccc_decoder_i_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE) -> sccc_decoder_i_sptr"""
    return _trellis_swig3.sccc_decoder_i_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE)

class sccc_decoder_i_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::sccc_decoder_blk< std::int32_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(sccc_decoder_i_sptr self) -> sccc_decoder_i_sptr
        __init__(sccc_decoder_i_sptr self, sccc_decoder_i p) -> sccc_decoder_i_sptr
        """
        _trellis_swig3.sccc_decoder_i_sptr_swiginit(self, _trellis_swig3.new_sccc_decoder_i_sptr(*args))

    def __deref__(self) -> "gr::trellis::sccc_decoder_blk< std::int32_t > *":
        r"""__deref__(sccc_decoder_i_sptr self) -> sccc_decoder_i"""
        return _trellis_swig3.sccc_decoder_i_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_i_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t") -> "gr::trellis::sccc_decoder_blk< int >::sptr":
        r"""make(sccc_decoder_i_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE) -> sccc_decoder_i_sptr"""
        return _trellis_swig3.sccc_decoder_i_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_i_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_i_sptr_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_i_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_i_sptr_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_i_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_i_sptr_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_i_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_i_sptr_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_i_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_i_sptr_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_i_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_i_sptr_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_i_sptr self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_i_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_i_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_i_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_i_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_i_sptr_repetitions(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_i_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_i_sptr_SISO_TYPE(self)

    def history(self) -> "unsigned int":
        r"""history(sccc_decoder_i_sptr self) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_i_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(sccc_decoder_i_sptr self, int which, int delay)
        declare_sample_delay(sccc_decoder_i_sptr self, unsigned int delay)
        """
        return _trellis_swig3.sccc_decoder_i_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(sccc_decoder_i_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_i_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(sccc_decoder_i_sptr self, int multiple)"""
        return _trellis_swig3.sccc_decoder_i_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(sccc_decoder_i_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_i_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(sccc_decoder_i_sptr self) -> double"""
        return _trellis_swig3.sccc_decoder_i_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(sccc_decoder_i_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_i_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(sccc_decoder_i_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_i_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(sccc_decoder_i_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_i_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(sccc_decoder_i_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_i_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(sccc_decoder_i_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_i_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(sccc_decoder_i_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_i_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(sccc_decoder_i_sptr self, std::string level)"""
        return _trellis_swig3.sccc_decoder_i_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(sccc_decoder_i_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_i_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(sccc_decoder_i_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_i_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(sccc_decoder_i_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_i_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(sccc_decoder_i_sptr self)"""
        return _trellis_swig3.sccc_decoder_i_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(sccc_decoder_i_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_i_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(sccc_decoder_i_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_i_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(sccc_decoder_i_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_i_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(sccc_decoder_i_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_i_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(sccc_decoder_i_sptr self, long max_output_buffer)
        set_max_output_buffer(sccc_decoder_i_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_i_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(sccc_decoder_i_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_i_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(sccc_decoder_i_sptr self, long min_output_buffer)
        set_min_output_buffer(sccc_decoder_i_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_i_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(sccc_decoder_i_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_i_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(sccc_decoder_i_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_i_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(sccc_decoder_i_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_i_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(sccc_decoder_i_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_i_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(sccc_decoder_i_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_i_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(sccc_decoder_i_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_i_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(sccc_decoder_i_sptr self, int which) -> float
        pc_input_buffers_full(sccc_decoder_i_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_i_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(sccc_decoder_i_sptr self, int which) -> float
        pc_input_buffers_full_avg(sccc_decoder_i_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_i_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(sccc_decoder_i_sptr self, int which) -> float
        pc_input_buffers_full_var(sccc_decoder_i_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_i_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(sccc_decoder_i_sptr self, int which) -> float
        pc_output_buffers_full(sccc_decoder_i_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_i_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(sccc_decoder_i_sptr self, int which) -> float
        pc_output_buffers_full_avg(sccc_decoder_i_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_i_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(sccc_decoder_i_sptr self, int which) -> float
        pc_output_buffers_full_var(sccc_decoder_i_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_i_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(sccc_decoder_i_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_i_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(sccc_decoder_i_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_i_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(sccc_decoder_i_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_i_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(sccc_decoder_i_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_i_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(sccc_decoder_i_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_i_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(sccc_decoder_i_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.sccc_decoder_i_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(sccc_decoder_i_sptr self)"""
        return _trellis_swig3.sccc_decoder_i_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(sccc_decoder_i_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.sccc_decoder_i_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(sccc_decoder_i_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_i_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(sccc_decoder_i_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_i_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(sccc_decoder_i_sptr self, int priority) -> int"""
        return _trellis_swig3.sccc_decoder_i_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(sccc_decoder_i_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_i_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(sccc_decoder_i_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_i_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(sccc_decoder_i_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_i_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(sccc_decoder_i_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_i_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(sccc_decoder_i_sptr self) -> long"""
        return _trellis_swig3.sccc_decoder_i_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(sccc_decoder_i_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.sccc_decoder_i_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(sccc_decoder_i_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.sccc_decoder_i_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(sccc_decoder_i_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_i_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(sccc_decoder_i_sptr self, std::string name)"""
        return _trellis_swig3.sccc_decoder_i_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(sccc_decoder_i_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.sccc_decoder_i_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(sccc_decoder_i_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_i_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(sccc_decoder_i_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_i_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(sccc_decoder_i_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_i_sptr_message_subscribers(self, which_port)

# Register sccc_decoder_i_sptr in _trellis_swig3:
_trellis_swig3.sccc_decoder_i_sptr_swigregister(sccc_decoder_i_sptr)


sccc_decoder_i_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
sccc_decoder_i = sccc_decoder_i.make

class sccc_decoder_combined_fb(object):
    r"""Proxy of C++ gr::trellis::sccc_decoder_combined_blk< float,std::uint8_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< float,unsigned char >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_fb_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fb_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_combined_fb self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_fb_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_combined_fb self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_fb_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_combined_fb self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_combined_fb self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_combined_fb self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_combined_fb self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_combined_fb self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_combined_fb_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_combined_fb self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_combined_fb self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_repetitions(self)

    def D(self) -> "int":
        r"""D(sccc_decoder_combined_fb self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_D(self)

    def TABLE(self) -> "std::vector< float,std::allocator< float > >":
        r"""TABLE(sccc_decoder_combined_fb self) -> pmt_vector_float"""
        return _trellis_swig3.sccc_decoder_combined_fb_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(sccc_decoder_combined_fb self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.sccc_decoder_combined_fb_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_combined_fb self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_combined_fb_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(sccc_decoder_combined_fb self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fb_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(sccc_decoder_combined_fb self, float scaling)"""
        return _trellis_swig3.sccc_decoder_combined_fb_set_scaling(self, scaling)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_combined_fb

# Register sccc_decoder_combined_fb in _trellis_swig3:
_trellis_swig3.sccc_decoder_combined_fb_swigregister(sccc_decoder_combined_fb)

def sccc_decoder_combined_fb_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< float,unsigned char >::sptr":
    r"""sccc_decoder_combined_fb_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_fb_sptr"""
    return _trellis_swig3.sccc_decoder_combined_fb_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

class sccc_decoder_combined_fb_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::sccc_decoder_combined_blk< float,std::uint8_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(sccc_decoder_combined_fb_sptr self) -> sccc_decoder_combined_fb_sptr
        __init__(sccc_decoder_combined_fb_sptr self, sccc_decoder_combined_fb p) -> sccc_decoder_combined_fb_sptr
        """
        _trellis_swig3.sccc_decoder_combined_fb_sptr_swiginit(self, _trellis_swig3.new_sccc_decoder_combined_fb_sptr(*args))

    def __deref__(self) -> "gr::trellis::sccc_decoder_combined_blk< float,std::uint8_t > *":
        r"""__deref__(sccc_decoder_combined_fb_sptr self) -> sccc_decoder_combined_fb"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_combined_fb_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< float,unsigned char >::sptr":
        r"""make(sccc_decoder_combined_fb_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_fb_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_combined_fb_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_combined_fb_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_combined_fb_sptr self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_repetitions(self)

    def D(self) -> "int":
        r"""D(sccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_D(self)

    def TABLE(self) -> "std::vector< float,std::allocator< float > >":
        r"""TABLE(sccc_decoder_combined_fb_sptr self) -> pmt_vector_float"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(sccc_decoder_combined_fb_sptr self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_combined_fb_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(sccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(sccc_decoder_combined_fb_sptr self, float scaling)"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_set_scaling(self, scaling)

    def history(self) -> "unsigned int":
        r"""history(sccc_decoder_combined_fb_sptr self) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(sccc_decoder_combined_fb_sptr self, int which, int delay)
        declare_sample_delay(sccc_decoder_combined_fb_sptr self, unsigned int delay)
        """
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(sccc_decoder_combined_fb_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(sccc_decoder_combined_fb_sptr self, int multiple)"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(sccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(sccc_decoder_combined_fb_sptr self) -> double"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(sccc_decoder_combined_fb_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(sccc_decoder_combined_fb_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(sccc_decoder_combined_fb_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(sccc_decoder_combined_fb_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(sccc_decoder_combined_fb_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(sccc_decoder_combined_fb_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(sccc_decoder_combined_fb_sptr self, std::string level)"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(sccc_decoder_combined_fb_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(sccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(sccc_decoder_combined_fb_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(sccc_decoder_combined_fb_sptr self)"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(sccc_decoder_combined_fb_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(sccc_decoder_combined_fb_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(sccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(sccc_decoder_combined_fb_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(sccc_decoder_combined_fb_sptr self, long max_output_buffer)
        set_max_output_buffer(sccc_decoder_combined_fb_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(sccc_decoder_combined_fb_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(sccc_decoder_combined_fb_sptr self, long min_output_buffer)
        set_min_output_buffer(sccc_decoder_combined_fb_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(sccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(sccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(sccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(sccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(sccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(sccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(sccc_decoder_combined_fb_sptr self, int which) -> float
        pc_input_buffers_full(sccc_decoder_combined_fb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(sccc_decoder_combined_fb_sptr self, int which) -> float
        pc_input_buffers_full_avg(sccc_decoder_combined_fb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(sccc_decoder_combined_fb_sptr self, int which) -> float
        pc_input_buffers_full_var(sccc_decoder_combined_fb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(sccc_decoder_combined_fb_sptr self, int which) -> float
        pc_output_buffers_full(sccc_decoder_combined_fb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(sccc_decoder_combined_fb_sptr self, int which) -> float
        pc_output_buffers_full_avg(sccc_decoder_combined_fb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(sccc_decoder_combined_fb_sptr self, int which) -> float
        pc_output_buffers_full_var(sccc_decoder_combined_fb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(sccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(sccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(sccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(sccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(sccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(sccc_decoder_combined_fb_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(sccc_decoder_combined_fb_sptr self)"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(sccc_decoder_combined_fb_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(sccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(sccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(sccc_decoder_combined_fb_sptr self, int priority) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(sccc_decoder_combined_fb_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(sccc_decoder_combined_fb_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(sccc_decoder_combined_fb_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(sccc_decoder_combined_fb_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(sccc_decoder_combined_fb_sptr self) -> long"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(sccc_decoder_combined_fb_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(sccc_decoder_combined_fb_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(sccc_decoder_combined_fb_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(sccc_decoder_combined_fb_sptr self, std::string name)"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(sccc_decoder_combined_fb_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(sccc_decoder_combined_fb_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(sccc_decoder_combined_fb_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(sccc_decoder_combined_fb_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_fb_sptr_message_subscribers(self, which_port)

# Register sccc_decoder_combined_fb_sptr in _trellis_swig3:
_trellis_swig3.sccc_decoder_combined_fb_sptr_swigregister(sccc_decoder_combined_fb_sptr)


sccc_decoder_combined_fb_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
sccc_decoder_combined_fb = sccc_decoder_combined_fb.make

class sccc_decoder_combined_fs(object):
    r"""Proxy of C++ gr::trellis::sccc_decoder_combined_blk< float,std::int16_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< float,short >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_fs_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fs_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_combined_fs self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_fs_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_combined_fs self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_fs_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_combined_fs self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_combined_fs self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_combined_fs self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_combined_fs self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_combined_fs self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_combined_fs_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_combined_fs self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_combined_fs self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_repetitions(self)

    def D(self) -> "int":
        r"""D(sccc_decoder_combined_fs self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_D(self)

    def TABLE(self) -> "std::vector< float,std::allocator< float > >":
        r"""TABLE(sccc_decoder_combined_fs self) -> pmt_vector_float"""
        return _trellis_swig3.sccc_decoder_combined_fs_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(sccc_decoder_combined_fs self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.sccc_decoder_combined_fs_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_combined_fs self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_combined_fs_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(sccc_decoder_combined_fs self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fs_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(sccc_decoder_combined_fs self, float scaling)"""
        return _trellis_swig3.sccc_decoder_combined_fs_set_scaling(self, scaling)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_combined_fs

# Register sccc_decoder_combined_fs in _trellis_swig3:
_trellis_swig3.sccc_decoder_combined_fs_swigregister(sccc_decoder_combined_fs)

def sccc_decoder_combined_fs_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< float,short >::sptr":
    r"""sccc_decoder_combined_fs_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_fs_sptr"""
    return _trellis_swig3.sccc_decoder_combined_fs_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

class sccc_decoder_combined_fs_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::sccc_decoder_combined_blk< float,std::int16_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(sccc_decoder_combined_fs_sptr self) -> sccc_decoder_combined_fs_sptr
        __init__(sccc_decoder_combined_fs_sptr self, sccc_decoder_combined_fs p) -> sccc_decoder_combined_fs_sptr
        """
        _trellis_swig3.sccc_decoder_combined_fs_sptr_swiginit(self, _trellis_swig3.new_sccc_decoder_combined_fs_sptr(*args))

    def __deref__(self) -> "gr::trellis::sccc_decoder_combined_blk< float,std::int16_t > *":
        r"""__deref__(sccc_decoder_combined_fs_sptr self) -> sccc_decoder_combined_fs"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_combined_fs_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< float,short >::sptr":
        r"""make(sccc_decoder_combined_fs_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_fs_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_combined_fs_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_combined_fs_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_combined_fs_sptr self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_repetitions(self)

    def D(self) -> "int":
        r"""D(sccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_D(self)

    def TABLE(self) -> "std::vector< float,std::allocator< float > >":
        r"""TABLE(sccc_decoder_combined_fs_sptr self) -> pmt_vector_float"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(sccc_decoder_combined_fs_sptr self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_combined_fs_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(sccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(sccc_decoder_combined_fs_sptr self, float scaling)"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_set_scaling(self, scaling)

    def history(self) -> "unsigned int":
        r"""history(sccc_decoder_combined_fs_sptr self) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(sccc_decoder_combined_fs_sptr self, int which, int delay)
        declare_sample_delay(sccc_decoder_combined_fs_sptr self, unsigned int delay)
        """
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(sccc_decoder_combined_fs_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(sccc_decoder_combined_fs_sptr self, int multiple)"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(sccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(sccc_decoder_combined_fs_sptr self) -> double"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(sccc_decoder_combined_fs_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(sccc_decoder_combined_fs_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(sccc_decoder_combined_fs_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(sccc_decoder_combined_fs_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(sccc_decoder_combined_fs_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(sccc_decoder_combined_fs_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(sccc_decoder_combined_fs_sptr self, std::string level)"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(sccc_decoder_combined_fs_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(sccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(sccc_decoder_combined_fs_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(sccc_decoder_combined_fs_sptr self)"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(sccc_decoder_combined_fs_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(sccc_decoder_combined_fs_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(sccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(sccc_decoder_combined_fs_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(sccc_decoder_combined_fs_sptr self, long max_output_buffer)
        set_max_output_buffer(sccc_decoder_combined_fs_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(sccc_decoder_combined_fs_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(sccc_decoder_combined_fs_sptr self, long min_output_buffer)
        set_min_output_buffer(sccc_decoder_combined_fs_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(sccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(sccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(sccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(sccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(sccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(sccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(sccc_decoder_combined_fs_sptr self, int which) -> float
        pc_input_buffers_full(sccc_decoder_combined_fs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(sccc_decoder_combined_fs_sptr self, int which) -> float
        pc_input_buffers_full_avg(sccc_decoder_combined_fs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(sccc_decoder_combined_fs_sptr self, int which) -> float
        pc_input_buffers_full_var(sccc_decoder_combined_fs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(sccc_decoder_combined_fs_sptr self, int which) -> float
        pc_output_buffers_full(sccc_decoder_combined_fs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(sccc_decoder_combined_fs_sptr self, int which) -> float
        pc_output_buffers_full_avg(sccc_decoder_combined_fs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(sccc_decoder_combined_fs_sptr self, int which) -> float
        pc_output_buffers_full_var(sccc_decoder_combined_fs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(sccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(sccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(sccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(sccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(sccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(sccc_decoder_combined_fs_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(sccc_decoder_combined_fs_sptr self)"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(sccc_decoder_combined_fs_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(sccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(sccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(sccc_decoder_combined_fs_sptr self, int priority) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(sccc_decoder_combined_fs_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(sccc_decoder_combined_fs_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(sccc_decoder_combined_fs_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(sccc_decoder_combined_fs_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(sccc_decoder_combined_fs_sptr self) -> long"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(sccc_decoder_combined_fs_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(sccc_decoder_combined_fs_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(sccc_decoder_combined_fs_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(sccc_decoder_combined_fs_sptr self, std::string name)"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(sccc_decoder_combined_fs_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(sccc_decoder_combined_fs_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(sccc_decoder_combined_fs_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(sccc_decoder_combined_fs_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_fs_sptr_message_subscribers(self, which_port)

# Register sccc_decoder_combined_fs_sptr in _trellis_swig3:
_trellis_swig3.sccc_decoder_combined_fs_sptr_swigregister(sccc_decoder_combined_fs_sptr)


sccc_decoder_combined_fs_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
sccc_decoder_combined_fs = sccc_decoder_combined_fs.make

class sccc_decoder_combined_fi(object):
    r"""Proxy of C++ gr::trellis::sccc_decoder_combined_blk< float,std::int32_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< float,int >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_fi_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fi_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_combined_fi self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_fi_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_combined_fi self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_fi_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_combined_fi self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_combined_fi self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_combined_fi self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_combined_fi self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_combined_fi self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_combined_fi_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_combined_fi self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_combined_fi self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_repetitions(self)

    def D(self) -> "int":
        r"""D(sccc_decoder_combined_fi self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_D(self)

    def TABLE(self) -> "std::vector< float,std::allocator< float > >":
        r"""TABLE(sccc_decoder_combined_fi self) -> pmt_vector_float"""
        return _trellis_swig3.sccc_decoder_combined_fi_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(sccc_decoder_combined_fi self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.sccc_decoder_combined_fi_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_combined_fi self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_combined_fi_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(sccc_decoder_combined_fi self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fi_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(sccc_decoder_combined_fi self, float scaling)"""
        return _trellis_swig3.sccc_decoder_combined_fi_set_scaling(self, scaling)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_combined_fi

# Register sccc_decoder_combined_fi in _trellis_swig3:
_trellis_swig3.sccc_decoder_combined_fi_swigregister(sccc_decoder_combined_fi)

def sccc_decoder_combined_fi_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< float,int >::sptr":
    r"""sccc_decoder_combined_fi_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_fi_sptr"""
    return _trellis_swig3.sccc_decoder_combined_fi_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

class sccc_decoder_combined_fi_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::sccc_decoder_combined_blk< float,std::int32_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(sccc_decoder_combined_fi_sptr self) -> sccc_decoder_combined_fi_sptr
        __init__(sccc_decoder_combined_fi_sptr self, sccc_decoder_combined_fi p) -> sccc_decoder_combined_fi_sptr
        """
        _trellis_swig3.sccc_decoder_combined_fi_sptr_swiginit(self, _trellis_swig3.new_sccc_decoder_combined_fi_sptr(*args))

    def __deref__(self) -> "gr::trellis::sccc_decoder_combined_blk< float,std::int32_t > *":
        r"""__deref__(sccc_decoder_combined_fi_sptr self) -> sccc_decoder_combined_fi"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_combined_fi_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< float,int >::sptr":
        r"""make(sccc_decoder_combined_fi_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_fi_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_combined_fi_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_combined_fi_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_combined_fi_sptr self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_repetitions(self)

    def D(self) -> "int":
        r"""D(sccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_D(self)

    def TABLE(self) -> "std::vector< float,std::allocator< float > >":
        r"""TABLE(sccc_decoder_combined_fi_sptr self) -> pmt_vector_float"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(sccc_decoder_combined_fi_sptr self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_combined_fi_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(sccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(sccc_decoder_combined_fi_sptr self, float scaling)"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_set_scaling(self, scaling)

    def history(self) -> "unsigned int":
        r"""history(sccc_decoder_combined_fi_sptr self) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(sccc_decoder_combined_fi_sptr self, int which, int delay)
        declare_sample_delay(sccc_decoder_combined_fi_sptr self, unsigned int delay)
        """
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(sccc_decoder_combined_fi_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(sccc_decoder_combined_fi_sptr self, int multiple)"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(sccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(sccc_decoder_combined_fi_sptr self) -> double"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(sccc_decoder_combined_fi_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(sccc_decoder_combined_fi_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(sccc_decoder_combined_fi_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(sccc_decoder_combined_fi_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(sccc_decoder_combined_fi_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(sccc_decoder_combined_fi_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(sccc_decoder_combined_fi_sptr self, std::string level)"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(sccc_decoder_combined_fi_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(sccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(sccc_decoder_combined_fi_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(sccc_decoder_combined_fi_sptr self)"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(sccc_decoder_combined_fi_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(sccc_decoder_combined_fi_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(sccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(sccc_decoder_combined_fi_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(sccc_decoder_combined_fi_sptr self, long max_output_buffer)
        set_max_output_buffer(sccc_decoder_combined_fi_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(sccc_decoder_combined_fi_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(sccc_decoder_combined_fi_sptr self, long min_output_buffer)
        set_min_output_buffer(sccc_decoder_combined_fi_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(sccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(sccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(sccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(sccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(sccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(sccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(sccc_decoder_combined_fi_sptr self, int which) -> float
        pc_input_buffers_full(sccc_decoder_combined_fi_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(sccc_decoder_combined_fi_sptr self, int which) -> float
        pc_input_buffers_full_avg(sccc_decoder_combined_fi_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(sccc_decoder_combined_fi_sptr self, int which) -> float
        pc_input_buffers_full_var(sccc_decoder_combined_fi_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(sccc_decoder_combined_fi_sptr self, int which) -> float
        pc_output_buffers_full(sccc_decoder_combined_fi_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(sccc_decoder_combined_fi_sptr self, int which) -> float
        pc_output_buffers_full_avg(sccc_decoder_combined_fi_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(sccc_decoder_combined_fi_sptr self, int which) -> float
        pc_output_buffers_full_var(sccc_decoder_combined_fi_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(sccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(sccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(sccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(sccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(sccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(sccc_decoder_combined_fi_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(sccc_decoder_combined_fi_sptr self)"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(sccc_decoder_combined_fi_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(sccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(sccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(sccc_decoder_combined_fi_sptr self, int priority) -> int"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(sccc_decoder_combined_fi_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(sccc_decoder_combined_fi_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(sccc_decoder_combined_fi_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(sccc_decoder_combined_fi_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(sccc_decoder_combined_fi_sptr self) -> long"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(sccc_decoder_combined_fi_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(sccc_decoder_combined_fi_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(sccc_decoder_combined_fi_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(sccc_decoder_combined_fi_sptr self, std::string name)"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(sccc_decoder_combined_fi_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(sccc_decoder_combined_fi_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(sccc_decoder_combined_fi_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(sccc_decoder_combined_fi_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_fi_sptr_message_subscribers(self, which_port)

# Register sccc_decoder_combined_fi_sptr in _trellis_swig3:
_trellis_swig3.sccc_decoder_combined_fi_sptr_swigregister(sccc_decoder_combined_fi_sptr)


sccc_decoder_combined_fi_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
sccc_decoder_combined_fi = sccc_decoder_combined_fi.make

class sccc_decoder_combined_cb(object):
    r"""Proxy of C++ gr::trellis::sccc_decoder_combined_blk< gr_complex,std::uint8_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< std::complex< float >,unsigned char >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_cb_sptr"""
        return _trellis_swig3.sccc_decoder_combined_cb_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_combined_cb self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_cb_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_combined_cb self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_cb_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_combined_cb self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_combined_cb self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_combined_cb self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_combined_cb self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_combined_cb self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_combined_cb_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_combined_cb self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_combined_cb self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_repetitions(self)

    def D(self) -> "int":
        r"""D(sccc_decoder_combined_cb self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_D(self)

    def TABLE(self) -> "std::vector< std::complex< float >,std::allocator< std::complex< float > > >":
        r"""TABLE(sccc_decoder_combined_cb self) -> pmt_vector_cfloat"""
        return _trellis_swig3.sccc_decoder_combined_cb_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(sccc_decoder_combined_cb self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.sccc_decoder_combined_cb_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_combined_cb self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_combined_cb_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(sccc_decoder_combined_cb self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cb_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(sccc_decoder_combined_cb self, float scaling)"""
        return _trellis_swig3.sccc_decoder_combined_cb_set_scaling(self, scaling)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_combined_cb

# Register sccc_decoder_combined_cb in _trellis_swig3:
_trellis_swig3.sccc_decoder_combined_cb_swigregister(sccc_decoder_combined_cb)

def sccc_decoder_combined_cb_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< std::complex< float >,unsigned char >::sptr":
    r"""sccc_decoder_combined_cb_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_cb_sptr"""
    return _trellis_swig3.sccc_decoder_combined_cb_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

class sccc_decoder_combined_cb_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::sccc_decoder_combined_blk< gr_complex,std::uint8_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(sccc_decoder_combined_cb_sptr self) -> sccc_decoder_combined_cb_sptr
        __init__(sccc_decoder_combined_cb_sptr self, sccc_decoder_combined_cb p) -> sccc_decoder_combined_cb_sptr
        """
        _trellis_swig3.sccc_decoder_combined_cb_sptr_swiginit(self, _trellis_swig3.new_sccc_decoder_combined_cb_sptr(*args))

    def __deref__(self) -> "gr::trellis::sccc_decoder_combined_blk< gr_complex,std::uint8_t > *":
        r"""__deref__(sccc_decoder_combined_cb_sptr self) -> sccc_decoder_combined_cb"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_combined_cb_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< std::complex< float >,unsigned char >::sptr":
        r"""make(sccc_decoder_combined_cb_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_cb_sptr"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_combined_cb_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_combined_cb_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_combined_cb_sptr self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_repetitions(self)

    def D(self) -> "int":
        r"""D(sccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_D(self)

    def TABLE(self) -> "std::vector< std::complex< float >,std::allocator< std::complex< float > > >":
        r"""TABLE(sccc_decoder_combined_cb_sptr self) -> pmt_vector_cfloat"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(sccc_decoder_combined_cb_sptr self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_combined_cb_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(sccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(sccc_decoder_combined_cb_sptr self, float scaling)"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_set_scaling(self, scaling)

    def history(self) -> "unsigned int":
        r"""history(sccc_decoder_combined_cb_sptr self) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(sccc_decoder_combined_cb_sptr self, int which, int delay)
        declare_sample_delay(sccc_decoder_combined_cb_sptr self, unsigned int delay)
        """
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(sccc_decoder_combined_cb_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(sccc_decoder_combined_cb_sptr self, int multiple)"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(sccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(sccc_decoder_combined_cb_sptr self) -> double"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(sccc_decoder_combined_cb_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(sccc_decoder_combined_cb_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(sccc_decoder_combined_cb_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(sccc_decoder_combined_cb_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(sccc_decoder_combined_cb_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(sccc_decoder_combined_cb_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(sccc_decoder_combined_cb_sptr self, std::string level)"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(sccc_decoder_combined_cb_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(sccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(sccc_decoder_combined_cb_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(sccc_decoder_combined_cb_sptr self)"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(sccc_decoder_combined_cb_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(sccc_decoder_combined_cb_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(sccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(sccc_decoder_combined_cb_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(sccc_decoder_combined_cb_sptr self, long max_output_buffer)
        set_max_output_buffer(sccc_decoder_combined_cb_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(sccc_decoder_combined_cb_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(sccc_decoder_combined_cb_sptr self, long min_output_buffer)
        set_min_output_buffer(sccc_decoder_combined_cb_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(sccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(sccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(sccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(sccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(sccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(sccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(sccc_decoder_combined_cb_sptr self, int which) -> float
        pc_input_buffers_full(sccc_decoder_combined_cb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(sccc_decoder_combined_cb_sptr self, int which) -> float
        pc_input_buffers_full_avg(sccc_decoder_combined_cb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(sccc_decoder_combined_cb_sptr self, int which) -> float
        pc_input_buffers_full_var(sccc_decoder_combined_cb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(sccc_decoder_combined_cb_sptr self, int which) -> float
        pc_output_buffers_full(sccc_decoder_combined_cb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(sccc_decoder_combined_cb_sptr self, int which) -> float
        pc_output_buffers_full_avg(sccc_decoder_combined_cb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(sccc_decoder_combined_cb_sptr self, int which) -> float
        pc_output_buffers_full_var(sccc_decoder_combined_cb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(sccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(sccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(sccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(sccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(sccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(sccc_decoder_combined_cb_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(sccc_decoder_combined_cb_sptr self)"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(sccc_decoder_combined_cb_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(sccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(sccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(sccc_decoder_combined_cb_sptr self, int priority) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(sccc_decoder_combined_cb_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(sccc_decoder_combined_cb_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(sccc_decoder_combined_cb_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(sccc_decoder_combined_cb_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(sccc_decoder_combined_cb_sptr self) -> long"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(sccc_decoder_combined_cb_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(sccc_decoder_combined_cb_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(sccc_decoder_combined_cb_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(sccc_decoder_combined_cb_sptr self, std::string name)"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(sccc_decoder_combined_cb_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(sccc_decoder_combined_cb_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(sccc_decoder_combined_cb_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(sccc_decoder_combined_cb_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_cb_sptr_message_subscribers(self, which_port)

# Register sccc_decoder_combined_cb_sptr in _trellis_swig3:
_trellis_swig3.sccc_decoder_combined_cb_sptr_swigregister(sccc_decoder_combined_cb_sptr)


sccc_decoder_combined_cb_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
sccc_decoder_combined_cb = sccc_decoder_combined_cb.make

class sccc_decoder_combined_cs(object):
    r"""Proxy of C++ gr::trellis::sccc_decoder_combined_blk< gr_complex,std::int16_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< std::complex< float >,short >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_cs_sptr"""
        return _trellis_swig3.sccc_decoder_combined_cs_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_combined_cs self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_cs_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_combined_cs self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_cs_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_combined_cs self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_combined_cs self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_combined_cs self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_combined_cs self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_combined_cs self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_combined_cs_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_combined_cs self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_combined_cs self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_repetitions(self)

    def D(self) -> "int":
        r"""D(sccc_decoder_combined_cs self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_D(self)

    def TABLE(self) -> "std::vector< std::complex< float >,std::allocator< std::complex< float > > >":
        r"""TABLE(sccc_decoder_combined_cs self) -> pmt_vector_cfloat"""
        return _trellis_swig3.sccc_decoder_combined_cs_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(sccc_decoder_combined_cs self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.sccc_decoder_combined_cs_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_combined_cs self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_combined_cs_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(sccc_decoder_combined_cs self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cs_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(sccc_decoder_combined_cs self, float scaling)"""
        return _trellis_swig3.sccc_decoder_combined_cs_set_scaling(self, scaling)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_combined_cs

# Register sccc_decoder_combined_cs in _trellis_swig3:
_trellis_swig3.sccc_decoder_combined_cs_swigregister(sccc_decoder_combined_cs)

def sccc_decoder_combined_cs_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< std::complex< float >,short >::sptr":
    r"""sccc_decoder_combined_cs_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_cs_sptr"""
    return _trellis_swig3.sccc_decoder_combined_cs_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

class sccc_decoder_combined_cs_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::sccc_decoder_combined_blk< gr_complex,std::int16_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(sccc_decoder_combined_cs_sptr self) -> sccc_decoder_combined_cs_sptr
        __init__(sccc_decoder_combined_cs_sptr self, sccc_decoder_combined_cs p) -> sccc_decoder_combined_cs_sptr
        """
        _trellis_swig3.sccc_decoder_combined_cs_sptr_swiginit(self, _trellis_swig3.new_sccc_decoder_combined_cs_sptr(*args))

    def __deref__(self) -> "gr::trellis::sccc_decoder_combined_blk< gr_complex,std::int16_t > *":
        r"""__deref__(sccc_decoder_combined_cs_sptr self) -> sccc_decoder_combined_cs"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_combined_cs_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< std::complex< float >,short >::sptr":
        r"""make(sccc_decoder_combined_cs_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_cs_sptr"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_combined_cs_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_combined_cs_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_combined_cs_sptr self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_repetitions(self)

    def D(self) -> "int":
        r"""D(sccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_D(self)

    def TABLE(self) -> "std::vector< std::complex< float >,std::allocator< std::complex< float > > >":
        r"""TABLE(sccc_decoder_combined_cs_sptr self) -> pmt_vector_cfloat"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(sccc_decoder_combined_cs_sptr self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_combined_cs_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(sccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(sccc_decoder_combined_cs_sptr self, float scaling)"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_set_scaling(self, scaling)

    def history(self) -> "unsigned int":
        r"""history(sccc_decoder_combined_cs_sptr self) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(sccc_decoder_combined_cs_sptr self, int which, int delay)
        declare_sample_delay(sccc_decoder_combined_cs_sptr self, unsigned int delay)
        """
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(sccc_decoder_combined_cs_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(sccc_decoder_combined_cs_sptr self, int multiple)"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(sccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(sccc_decoder_combined_cs_sptr self) -> double"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(sccc_decoder_combined_cs_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(sccc_decoder_combined_cs_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(sccc_decoder_combined_cs_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(sccc_decoder_combined_cs_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(sccc_decoder_combined_cs_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(sccc_decoder_combined_cs_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(sccc_decoder_combined_cs_sptr self, std::string level)"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(sccc_decoder_combined_cs_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(sccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(sccc_decoder_combined_cs_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(sccc_decoder_combined_cs_sptr self)"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(sccc_decoder_combined_cs_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(sccc_decoder_combined_cs_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(sccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(sccc_decoder_combined_cs_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(sccc_decoder_combined_cs_sptr self, long max_output_buffer)
        set_max_output_buffer(sccc_decoder_combined_cs_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(sccc_decoder_combined_cs_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(sccc_decoder_combined_cs_sptr self, long min_output_buffer)
        set_min_output_buffer(sccc_decoder_combined_cs_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(sccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(sccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(sccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(sccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(sccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(sccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(sccc_decoder_combined_cs_sptr self, int which) -> float
        pc_input_buffers_full(sccc_decoder_combined_cs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(sccc_decoder_combined_cs_sptr self, int which) -> float
        pc_input_buffers_full_avg(sccc_decoder_combined_cs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(sccc_decoder_combined_cs_sptr self, int which) -> float
        pc_input_buffers_full_var(sccc_decoder_combined_cs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(sccc_decoder_combined_cs_sptr self, int which) -> float
        pc_output_buffers_full(sccc_decoder_combined_cs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(sccc_decoder_combined_cs_sptr self, int which) -> float
        pc_output_buffers_full_avg(sccc_decoder_combined_cs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(sccc_decoder_combined_cs_sptr self, int which) -> float
        pc_output_buffers_full_var(sccc_decoder_combined_cs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(sccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(sccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(sccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(sccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(sccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(sccc_decoder_combined_cs_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(sccc_decoder_combined_cs_sptr self)"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(sccc_decoder_combined_cs_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(sccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(sccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(sccc_decoder_combined_cs_sptr self, int priority) -> int"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(sccc_decoder_combined_cs_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(sccc_decoder_combined_cs_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(sccc_decoder_combined_cs_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(sccc_decoder_combined_cs_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(sccc_decoder_combined_cs_sptr self) -> long"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(sccc_decoder_combined_cs_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(sccc_decoder_combined_cs_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(sccc_decoder_combined_cs_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(sccc_decoder_combined_cs_sptr self, std::string name)"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(sccc_decoder_combined_cs_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(sccc_decoder_combined_cs_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(sccc_decoder_combined_cs_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(sccc_decoder_combined_cs_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_cs_sptr_message_subscribers(self, which_port)

# Register sccc_decoder_combined_cs_sptr in _trellis_swig3:
_trellis_swig3.sccc_decoder_combined_cs_sptr_swigregister(sccc_decoder_combined_cs_sptr)


sccc_decoder_combined_cs_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
sccc_decoder_combined_cs = sccc_decoder_combined_cs.make

class sccc_decoder_combined_ci(object):
    r"""Proxy of C++ gr::trellis::sccc_decoder_combined_blk< gr_complex,std::int32_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< std::complex< float >,int >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_ci_sptr"""
        return _trellis_swig3.sccc_decoder_combined_ci_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_combined_ci self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_ci_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_combined_ci self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_ci_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_combined_ci self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_combined_ci self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_combined_ci self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_combined_ci self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_combined_ci self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_combined_ci_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_combined_ci self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_combined_ci self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_repetitions(self)

    def D(self) -> "int":
        r"""D(sccc_decoder_combined_ci self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_D(self)

    def TABLE(self) -> "std::vector< std::complex< float >,std::allocator< std::complex< float > > >":
        r"""TABLE(sccc_decoder_combined_ci self) -> pmt_vector_cfloat"""
        return _trellis_swig3.sccc_decoder_combined_ci_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(sccc_decoder_combined_ci self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.sccc_decoder_combined_ci_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_combined_ci self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_combined_ci_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(sccc_decoder_combined_ci self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_ci_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(sccc_decoder_combined_ci self, float scaling)"""
        return _trellis_swig3.sccc_decoder_combined_ci_set_scaling(self, scaling)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_combined_ci

# Register sccc_decoder_combined_ci in _trellis_swig3:
_trellis_swig3.sccc_decoder_combined_ci_swigregister(sccc_decoder_combined_ci)

def sccc_decoder_combined_ci_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< std::complex< float >,int >::sptr":
    r"""sccc_decoder_combined_ci_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_ci_sptr"""
    return _trellis_swig3.sccc_decoder_combined_ci_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

class sccc_decoder_combined_ci_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::sccc_decoder_combined_blk< gr_complex,std::int32_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(sccc_decoder_combined_ci_sptr self) -> sccc_decoder_combined_ci_sptr
        __init__(sccc_decoder_combined_ci_sptr self, sccc_decoder_combined_ci p) -> sccc_decoder_combined_ci_sptr
        """
        _trellis_swig3.sccc_decoder_combined_ci_sptr_swiginit(self, _trellis_swig3.new_sccc_decoder_combined_ci_sptr(*args))

    def __deref__(self) -> "gr::trellis::sccc_decoder_combined_blk< gr_complex,std::int32_t > *":
        r"""__deref__(sccc_decoder_combined_ci_sptr self) -> sccc_decoder_combined_ci"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_sccc_decoder_combined_ci_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::sccc_decoder_combined_blk< std::complex< float >,int >::sptr":
        r"""make(sccc_decoder_combined_ci_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> sccc_decoder_combined_ci_sptr"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSMo(self) -> "gr::trellis::fsm":
        r"""FSMo(sccc_decoder_combined_ci_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_FSMo(self)

    def FSMi(self) -> "gr::trellis::fsm":
        r"""FSMi(sccc_decoder_combined_ci_sptr self) -> fsm"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_FSMi(self)

    def STo0(self) -> "int":
        r"""STo0(sccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_STo0(self)

    def SToK(self) -> "int":
        r"""SToK(sccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_SToK(self)

    def STi0(self) -> "int":
        r"""STi0(sccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_STi0(self)

    def STiK(self) -> "int":
        r"""STiK(sccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_STiK(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(sccc_decoder_combined_ci_sptr self) -> interleaver"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(sccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(sccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_repetitions(self)

    def D(self) -> "int":
        r"""D(sccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_D(self)

    def TABLE(self) -> "std::vector< std::complex< float >,std::allocator< std::complex< float > > >":
        r"""TABLE(sccc_decoder_combined_ci_sptr self) -> pmt_vector_cfloat"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(sccc_decoder_combined_ci_sptr self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(sccc_decoder_combined_ci_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(sccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(sccc_decoder_combined_ci_sptr self, float scaling)"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_set_scaling(self, scaling)

    def history(self) -> "unsigned int":
        r"""history(sccc_decoder_combined_ci_sptr self) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(sccc_decoder_combined_ci_sptr self, int which, int delay)
        declare_sample_delay(sccc_decoder_combined_ci_sptr self, unsigned int delay)
        """
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(sccc_decoder_combined_ci_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(sccc_decoder_combined_ci_sptr self, int multiple)"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(sccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(sccc_decoder_combined_ci_sptr self) -> double"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(sccc_decoder_combined_ci_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(sccc_decoder_combined_ci_sptr self) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(sccc_decoder_combined_ci_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(sccc_decoder_combined_ci_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(sccc_decoder_combined_ci_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(sccc_decoder_combined_ci_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(sccc_decoder_combined_ci_sptr self, std::string level)"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(sccc_decoder_combined_ci_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(sccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(sccc_decoder_combined_ci_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(sccc_decoder_combined_ci_sptr self)"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(sccc_decoder_combined_ci_sptr self) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(sccc_decoder_combined_ci_sptr self, int m)"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(sccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(sccc_decoder_combined_ci_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(sccc_decoder_combined_ci_sptr self, long max_output_buffer)
        set_max_output_buffer(sccc_decoder_combined_ci_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(sccc_decoder_combined_ci_sptr self, int i) -> long"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(sccc_decoder_combined_ci_sptr self, long min_output_buffer)
        set_min_output_buffer(sccc_decoder_combined_ci_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(sccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(sccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(sccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(sccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(sccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(sccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(sccc_decoder_combined_ci_sptr self, int which) -> float
        pc_input_buffers_full(sccc_decoder_combined_ci_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(sccc_decoder_combined_ci_sptr self, int which) -> float
        pc_input_buffers_full_avg(sccc_decoder_combined_ci_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(sccc_decoder_combined_ci_sptr self, int which) -> float
        pc_input_buffers_full_var(sccc_decoder_combined_ci_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(sccc_decoder_combined_ci_sptr self, int which) -> float
        pc_output_buffers_full(sccc_decoder_combined_ci_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(sccc_decoder_combined_ci_sptr self, int which) -> float
        pc_output_buffers_full_avg(sccc_decoder_combined_ci_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(sccc_decoder_combined_ci_sptr self, int which) -> float
        pc_output_buffers_full_var(sccc_decoder_combined_ci_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(sccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(sccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(sccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(sccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(sccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(sccc_decoder_combined_ci_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(sccc_decoder_combined_ci_sptr self)"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(sccc_decoder_combined_ci_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(sccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(sccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(sccc_decoder_combined_ci_sptr self, int priority) -> int"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(sccc_decoder_combined_ci_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(sccc_decoder_combined_ci_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(sccc_decoder_combined_ci_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(sccc_decoder_combined_ci_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(sccc_decoder_combined_ci_sptr self) -> long"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(sccc_decoder_combined_ci_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(sccc_decoder_combined_ci_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(sccc_decoder_combined_ci_sptr self) -> std::string"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(sccc_decoder_combined_ci_sptr self, std::string name)"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(sccc_decoder_combined_ci_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(sccc_decoder_combined_ci_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(sccc_decoder_combined_ci_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(sccc_decoder_combined_ci_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.sccc_decoder_combined_ci_sptr_message_subscribers(self, which_port)

# Register sccc_decoder_combined_ci_sptr in _trellis_swig3:
_trellis_swig3.sccc_decoder_combined_ci_sptr_swigregister(sccc_decoder_combined_ci_sptr)


sccc_decoder_combined_ci_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
sccc_decoder_combined_ci = sccc_decoder_combined_ci.make

class pccc_decoder_combined_fb(object):
    r"""Proxy of C++ gr::trellis::pccc_decoder_combined_blk< float,std::uint8_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< float,unsigned char >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_fb_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fb_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSM1(self) -> "gr::trellis::fsm":
        r"""FSM1(pccc_decoder_combined_fb self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_fb_FSM1(self)

    def FSM2(self) -> "gr::trellis::fsm":
        r"""FSM2(pccc_decoder_combined_fb self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_fb_FSM2(self)

    def ST10(self) -> "int":
        r"""ST10(pccc_decoder_combined_fb self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_ST10(self)

    def ST1K(self) -> "int":
        r"""ST1K(pccc_decoder_combined_fb self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_ST1K(self)

    def ST20(self) -> "int":
        r"""ST20(pccc_decoder_combined_fb self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_ST20(self)

    def ST2K(self) -> "int":
        r"""ST2K(pccc_decoder_combined_fb self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_ST2K(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(pccc_decoder_combined_fb self) -> interleaver"""
        return _trellis_swig3.pccc_decoder_combined_fb_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(pccc_decoder_combined_fb self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(pccc_decoder_combined_fb self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_repetitions(self)

    def D(self) -> "int":
        r"""D(pccc_decoder_combined_fb self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_D(self)

    def TABLE(self) -> "std::vector< float,std::allocator< float > >":
        r"""TABLE(pccc_decoder_combined_fb self) -> pmt_vector_float"""
        return _trellis_swig3.pccc_decoder_combined_fb_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(pccc_decoder_combined_fb self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.pccc_decoder_combined_fb_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(pccc_decoder_combined_fb self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.pccc_decoder_combined_fb_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(pccc_decoder_combined_fb self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fb_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(pccc_decoder_combined_fb self, float scaling)"""
        return _trellis_swig3.pccc_decoder_combined_fb_set_scaling(self, scaling)
    __swig_destroy__ = _trellis_swig3.delete_pccc_decoder_combined_fb

# Register pccc_decoder_combined_fb in _trellis_swig3:
_trellis_swig3.pccc_decoder_combined_fb_swigregister(pccc_decoder_combined_fb)

def pccc_decoder_combined_fb_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< float,unsigned char >::sptr":
    r"""pccc_decoder_combined_fb_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_fb_sptr"""
    return _trellis_swig3.pccc_decoder_combined_fb_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

class pccc_decoder_combined_fb_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::pccc_decoder_combined_blk< float,std::uint8_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(pccc_decoder_combined_fb_sptr self) -> pccc_decoder_combined_fb_sptr
        __init__(pccc_decoder_combined_fb_sptr self, pccc_decoder_combined_fb p) -> pccc_decoder_combined_fb_sptr
        """
        _trellis_swig3.pccc_decoder_combined_fb_sptr_swiginit(self, _trellis_swig3.new_pccc_decoder_combined_fb_sptr(*args))

    def __deref__(self) -> "gr::trellis::pccc_decoder_combined_blk< float,std::uint8_t > *":
        r"""__deref__(pccc_decoder_combined_fb_sptr self) -> pccc_decoder_combined_fb"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_pccc_decoder_combined_fb_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< float,unsigned char >::sptr":
        r"""make(pccc_decoder_combined_fb_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_fb_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSM1(self) -> "gr::trellis::fsm":
        r"""FSM1(pccc_decoder_combined_fb_sptr self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_FSM1(self)

    def FSM2(self) -> "gr::trellis::fsm":
        r"""FSM2(pccc_decoder_combined_fb_sptr self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_FSM2(self)

    def ST10(self) -> "int":
        r"""ST10(pccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_ST10(self)

    def ST1K(self) -> "int":
        r"""ST1K(pccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_ST1K(self)

    def ST20(self) -> "int":
        r"""ST20(pccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_ST20(self)

    def ST2K(self) -> "int":
        r"""ST2K(pccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_ST2K(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(pccc_decoder_combined_fb_sptr self) -> interleaver"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(pccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(pccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_repetitions(self)

    def D(self) -> "int":
        r"""D(pccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_D(self)

    def TABLE(self) -> "std::vector< float,std::allocator< float > >":
        r"""TABLE(pccc_decoder_combined_fb_sptr self) -> pmt_vector_float"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(pccc_decoder_combined_fb_sptr self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(pccc_decoder_combined_fb_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(pccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(pccc_decoder_combined_fb_sptr self, float scaling)"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_set_scaling(self, scaling)

    def history(self) -> "unsigned int":
        r"""history(pccc_decoder_combined_fb_sptr self) -> unsigned int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(pccc_decoder_combined_fb_sptr self, int which, int delay)
        declare_sample_delay(pccc_decoder_combined_fb_sptr self, unsigned int delay)
        """
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(pccc_decoder_combined_fb_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(pccc_decoder_combined_fb_sptr self, int multiple)"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(pccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(pccc_decoder_combined_fb_sptr self) -> double"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(pccc_decoder_combined_fb_sptr self) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(pccc_decoder_combined_fb_sptr self) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(pccc_decoder_combined_fb_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(pccc_decoder_combined_fb_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(pccc_decoder_combined_fb_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(pccc_decoder_combined_fb_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(pccc_decoder_combined_fb_sptr self, std::string level)"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(pccc_decoder_combined_fb_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(pccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(pccc_decoder_combined_fb_sptr self, int m)"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(pccc_decoder_combined_fb_sptr self)"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(pccc_decoder_combined_fb_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(pccc_decoder_combined_fb_sptr self, int m)"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(pccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(pccc_decoder_combined_fb_sptr self, int i) -> long"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(pccc_decoder_combined_fb_sptr self, long max_output_buffer)
        set_max_output_buffer(pccc_decoder_combined_fb_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(pccc_decoder_combined_fb_sptr self, int i) -> long"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(pccc_decoder_combined_fb_sptr self, long min_output_buffer)
        set_min_output_buffer(pccc_decoder_combined_fb_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(pccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(pccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(pccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(pccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(pccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(pccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(pccc_decoder_combined_fb_sptr self, int which) -> float
        pc_input_buffers_full(pccc_decoder_combined_fb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(pccc_decoder_combined_fb_sptr self, int which) -> float
        pc_input_buffers_full_avg(pccc_decoder_combined_fb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(pccc_decoder_combined_fb_sptr self, int which) -> float
        pc_input_buffers_full_var(pccc_decoder_combined_fb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(pccc_decoder_combined_fb_sptr self, int which) -> float
        pc_output_buffers_full(pccc_decoder_combined_fb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(pccc_decoder_combined_fb_sptr self, int which) -> float
        pc_output_buffers_full_avg(pccc_decoder_combined_fb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(pccc_decoder_combined_fb_sptr self, int which) -> float
        pc_output_buffers_full_var(pccc_decoder_combined_fb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(pccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(pccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(pccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(pccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(pccc_decoder_combined_fb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(pccc_decoder_combined_fb_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(pccc_decoder_combined_fb_sptr self)"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(pccc_decoder_combined_fb_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(pccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(pccc_decoder_combined_fb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(pccc_decoder_combined_fb_sptr self, int priority) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(pccc_decoder_combined_fb_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(pccc_decoder_combined_fb_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(pccc_decoder_combined_fb_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(pccc_decoder_combined_fb_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(pccc_decoder_combined_fb_sptr self) -> long"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(pccc_decoder_combined_fb_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(pccc_decoder_combined_fb_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(pccc_decoder_combined_fb_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(pccc_decoder_combined_fb_sptr self, std::string name)"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(pccc_decoder_combined_fb_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(pccc_decoder_combined_fb_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(pccc_decoder_combined_fb_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(pccc_decoder_combined_fb_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_fb_sptr_message_subscribers(self, which_port)

# Register pccc_decoder_combined_fb_sptr in _trellis_swig3:
_trellis_swig3.pccc_decoder_combined_fb_sptr_swigregister(pccc_decoder_combined_fb_sptr)


pccc_decoder_combined_fb_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
pccc_decoder_combined_fb = pccc_decoder_combined_fb.make

class pccc_decoder_combined_fs(object):
    r"""Proxy of C++ gr::trellis::pccc_decoder_combined_blk< float,std::int16_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< float,short >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_fs_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fs_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSM1(self) -> "gr::trellis::fsm":
        r"""FSM1(pccc_decoder_combined_fs self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_fs_FSM1(self)

    def FSM2(self) -> "gr::trellis::fsm":
        r"""FSM2(pccc_decoder_combined_fs self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_fs_FSM2(self)

    def ST10(self) -> "int":
        r"""ST10(pccc_decoder_combined_fs self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_ST10(self)

    def ST1K(self) -> "int":
        r"""ST1K(pccc_decoder_combined_fs self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_ST1K(self)

    def ST20(self) -> "int":
        r"""ST20(pccc_decoder_combined_fs self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_ST20(self)

    def ST2K(self) -> "int":
        r"""ST2K(pccc_decoder_combined_fs self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_ST2K(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(pccc_decoder_combined_fs self) -> interleaver"""
        return _trellis_swig3.pccc_decoder_combined_fs_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(pccc_decoder_combined_fs self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(pccc_decoder_combined_fs self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_repetitions(self)

    def D(self) -> "int":
        r"""D(pccc_decoder_combined_fs self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_D(self)

    def TABLE(self) -> "std::vector< float,std::allocator< float > >":
        r"""TABLE(pccc_decoder_combined_fs self) -> pmt_vector_float"""
        return _trellis_swig3.pccc_decoder_combined_fs_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(pccc_decoder_combined_fs self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.pccc_decoder_combined_fs_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(pccc_decoder_combined_fs self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.pccc_decoder_combined_fs_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(pccc_decoder_combined_fs self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fs_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(pccc_decoder_combined_fs self, float scaling)"""
        return _trellis_swig3.pccc_decoder_combined_fs_set_scaling(self, scaling)
    __swig_destroy__ = _trellis_swig3.delete_pccc_decoder_combined_fs

# Register pccc_decoder_combined_fs in _trellis_swig3:
_trellis_swig3.pccc_decoder_combined_fs_swigregister(pccc_decoder_combined_fs)

def pccc_decoder_combined_fs_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< float,short >::sptr":
    r"""pccc_decoder_combined_fs_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_fs_sptr"""
    return _trellis_swig3.pccc_decoder_combined_fs_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

class pccc_decoder_combined_fs_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::pccc_decoder_combined_blk< float,std::int16_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(pccc_decoder_combined_fs_sptr self) -> pccc_decoder_combined_fs_sptr
        __init__(pccc_decoder_combined_fs_sptr self, pccc_decoder_combined_fs p) -> pccc_decoder_combined_fs_sptr
        """
        _trellis_swig3.pccc_decoder_combined_fs_sptr_swiginit(self, _trellis_swig3.new_pccc_decoder_combined_fs_sptr(*args))

    def __deref__(self) -> "gr::trellis::pccc_decoder_combined_blk< float,std::int16_t > *":
        r"""__deref__(pccc_decoder_combined_fs_sptr self) -> pccc_decoder_combined_fs"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_pccc_decoder_combined_fs_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< float,short >::sptr":
        r"""make(pccc_decoder_combined_fs_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_fs_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSM1(self) -> "gr::trellis::fsm":
        r"""FSM1(pccc_decoder_combined_fs_sptr self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_FSM1(self)

    def FSM2(self) -> "gr::trellis::fsm":
        r"""FSM2(pccc_decoder_combined_fs_sptr self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_FSM2(self)

    def ST10(self) -> "int":
        r"""ST10(pccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_ST10(self)

    def ST1K(self) -> "int":
        r"""ST1K(pccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_ST1K(self)

    def ST20(self) -> "int":
        r"""ST20(pccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_ST20(self)

    def ST2K(self) -> "int":
        r"""ST2K(pccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_ST2K(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(pccc_decoder_combined_fs_sptr self) -> interleaver"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(pccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(pccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_repetitions(self)

    def D(self) -> "int":
        r"""D(pccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_D(self)

    def TABLE(self) -> "std::vector< float,std::allocator< float > >":
        r"""TABLE(pccc_decoder_combined_fs_sptr self) -> pmt_vector_float"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(pccc_decoder_combined_fs_sptr self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(pccc_decoder_combined_fs_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(pccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(pccc_decoder_combined_fs_sptr self, float scaling)"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_set_scaling(self, scaling)

    def history(self) -> "unsigned int":
        r"""history(pccc_decoder_combined_fs_sptr self) -> unsigned int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(pccc_decoder_combined_fs_sptr self, int which, int delay)
        declare_sample_delay(pccc_decoder_combined_fs_sptr self, unsigned int delay)
        """
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(pccc_decoder_combined_fs_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(pccc_decoder_combined_fs_sptr self, int multiple)"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(pccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(pccc_decoder_combined_fs_sptr self) -> double"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(pccc_decoder_combined_fs_sptr self) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(pccc_decoder_combined_fs_sptr self) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(pccc_decoder_combined_fs_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(pccc_decoder_combined_fs_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(pccc_decoder_combined_fs_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(pccc_decoder_combined_fs_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(pccc_decoder_combined_fs_sptr self, std::string level)"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(pccc_decoder_combined_fs_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(pccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(pccc_decoder_combined_fs_sptr self, int m)"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(pccc_decoder_combined_fs_sptr self)"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(pccc_decoder_combined_fs_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(pccc_decoder_combined_fs_sptr self, int m)"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(pccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(pccc_decoder_combined_fs_sptr self, int i) -> long"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(pccc_decoder_combined_fs_sptr self, long max_output_buffer)
        set_max_output_buffer(pccc_decoder_combined_fs_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(pccc_decoder_combined_fs_sptr self, int i) -> long"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(pccc_decoder_combined_fs_sptr self, long min_output_buffer)
        set_min_output_buffer(pccc_decoder_combined_fs_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(pccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(pccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(pccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(pccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(pccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(pccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(pccc_decoder_combined_fs_sptr self, int which) -> float
        pc_input_buffers_full(pccc_decoder_combined_fs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(pccc_decoder_combined_fs_sptr self, int which) -> float
        pc_input_buffers_full_avg(pccc_decoder_combined_fs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(pccc_decoder_combined_fs_sptr self, int which) -> float
        pc_input_buffers_full_var(pccc_decoder_combined_fs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(pccc_decoder_combined_fs_sptr self, int which) -> float
        pc_output_buffers_full(pccc_decoder_combined_fs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(pccc_decoder_combined_fs_sptr self, int which) -> float
        pc_output_buffers_full_avg(pccc_decoder_combined_fs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(pccc_decoder_combined_fs_sptr self, int which) -> float
        pc_output_buffers_full_var(pccc_decoder_combined_fs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(pccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(pccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(pccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(pccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(pccc_decoder_combined_fs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(pccc_decoder_combined_fs_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(pccc_decoder_combined_fs_sptr self)"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(pccc_decoder_combined_fs_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(pccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(pccc_decoder_combined_fs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(pccc_decoder_combined_fs_sptr self, int priority) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(pccc_decoder_combined_fs_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(pccc_decoder_combined_fs_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(pccc_decoder_combined_fs_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(pccc_decoder_combined_fs_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(pccc_decoder_combined_fs_sptr self) -> long"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(pccc_decoder_combined_fs_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(pccc_decoder_combined_fs_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(pccc_decoder_combined_fs_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(pccc_decoder_combined_fs_sptr self, std::string name)"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(pccc_decoder_combined_fs_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(pccc_decoder_combined_fs_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(pccc_decoder_combined_fs_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(pccc_decoder_combined_fs_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_fs_sptr_message_subscribers(self, which_port)

# Register pccc_decoder_combined_fs_sptr in _trellis_swig3:
_trellis_swig3.pccc_decoder_combined_fs_sptr_swigregister(pccc_decoder_combined_fs_sptr)


pccc_decoder_combined_fs_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
pccc_decoder_combined_fs = pccc_decoder_combined_fs.make

class pccc_decoder_combined_fi(object):
    r"""Proxy of C++ gr::trellis::pccc_decoder_combined_blk< float,std::int32_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< float,int >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_fi_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fi_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSM1(self) -> "gr::trellis::fsm":
        r"""FSM1(pccc_decoder_combined_fi self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_fi_FSM1(self)

    def FSM2(self) -> "gr::trellis::fsm":
        r"""FSM2(pccc_decoder_combined_fi self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_fi_FSM2(self)

    def ST10(self) -> "int":
        r"""ST10(pccc_decoder_combined_fi self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_ST10(self)

    def ST1K(self) -> "int":
        r"""ST1K(pccc_decoder_combined_fi self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_ST1K(self)

    def ST20(self) -> "int":
        r"""ST20(pccc_decoder_combined_fi self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_ST20(self)

    def ST2K(self) -> "int":
        r"""ST2K(pccc_decoder_combined_fi self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_ST2K(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(pccc_decoder_combined_fi self) -> interleaver"""
        return _trellis_swig3.pccc_decoder_combined_fi_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(pccc_decoder_combined_fi self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(pccc_decoder_combined_fi self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_repetitions(self)

    def D(self) -> "int":
        r"""D(pccc_decoder_combined_fi self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_D(self)

    def TABLE(self) -> "std::vector< float,std::allocator< float > >":
        r"""TABLE(pccc_decoder_combined_fi self) -> pmt_vector_float"""
        return _trellis_swig3.pccc_decoder_combined_fi_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(pccc_decoder_combined_fi self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.pccc_decoder_combined_fi_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(pccc_decoder_combined_fi self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.pccc_decoder_combined_fi_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(pccc_decoder_combined_fi self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fi_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(pccc_decoder_combined_fi self, float scaling)"""
        return _trellis_swig3.pccc_decoder_combined_fi_set_scaling(self, scaling)
    __swig_destroy__ = _trellis_swig3.delete_pccc_decoder_combined_fi

# Register pccc_decoder_combined_fi in _trellis_swig3:
_trellis_swig3.pccc_decoder_combined_fi_swigregister(pccc_decoder_combined_fi)

def pccc_decoder_combined_fi_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< float,int >::sptr":
    r"""pccc_decoder_combined_fi_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_fi_sptr"""
    return _trellis_swig3.pccc_decoder_combined_fi_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

class pccc_decoder_combined_fi_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::pccc_decoder_combined_blk< float,std::int32_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(pccc_decoder_combined_fi_sptr self) -> pccc_decoder_combined_fi_sptr
        __init__(pccc_decoder_combined_fi_sptr self, pccc_decoder_combined_fi p) -> pccc_decoder_combined_fi_sptr
        """
        _trellis_swig3.pccc_decoder_combined_fi_sptr_swiginit(self, _trellis_swig3.new_pccc_decoder_combined_fi_sptr(*args))

    def __deref__(self) -> "gr::trellis::pccc_decoder_combined_blk< float,std::int32_t > *":
        r"""__deref__(pccc_decoder_combined_fi_sptr self) -> pccc_decoder_combined_fi"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_pccc_decoder_combined_fi_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_float", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< float,int >::sptr":
        r"""make(pccc_decoder_combined_fi_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_float TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_fi_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSM1(self) -> "gr::trellis::fsm":
        r"""FSM1(pccc_decoder_combined_fi_sptr self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_FSM1(self)

    def FSM2(self) -> "gr::trellis::fsm":
        r"""FSM2(pccc_decoder_combined_fi_sptr self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_FSM2(self)

    def ST10(self) -> "int":
        r"""ST10(pccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_ST10(self)

    def ST1K(self) -> "int":
        r"""ST1K(pccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_ST1K(self)

    def ST20(self) -> "int":
        r"""ST20(pccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_ST20(self)

    def ST2K(self) -> "int":
        r"""ST2K(pccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_ST2K(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(pccc_decoder_combined_fi_sptr self) -> interleaver"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(pccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(pccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_repetitions(self)

    def D(self) -> "int":
        r"""D(pccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_D(self)

    def TABLE(self) -> "std::vector< float,std::allocator< float > >":
        r"""TABLE(pccc_decoder_combined_fi_sptr self) -> pmt_vector_float"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(pccc_decoder_combined_fi_sptr self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(pccc_decoder_combined_fi_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(pccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(pccc_decoder_combined_fi_sptr self, float scaling)"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_set_scaling(self, scaling)

    def history(self) -> "unsigned int":
        r"""history(pccc_decoder_combined_fi_sptr self) -> unsigned int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(pccc_decoder_combined_fi_sptr self, int which, int delay)
        declare_sample_delay(pccc_decoder_combined_fi_sptr self, unsigned int delay)
        """
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(pccc_decoder_combined_fi_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(pccc_decoder_combined_fi_sptr self, int multiple)"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(pccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(pccc_decoder_combined_fi_sptr self) -> double"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(pccc_decoder_combined_fi_sptr self) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(pccc_decoder_combined_fi_sptr self) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(pccc_decoder_combined_fi_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(pccc_decoder_combined_fi_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(pccc_decoder_combined_fi_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(pccc_decoder_combined_fi_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(pccc_decoder_combined_fi_sptr self, std::string level)"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(pccc_decoder_combined_fi_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(pccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(pccc_decoder_combined_fi_sptr self, int m)"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(pccc_decoder_combined_fi_sptr self)"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(pccc_decoder_combined_fi_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(pccc_decoder_combined_fi_sptr self, int m)"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(pccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(pccc_decoder_combined_fi_sptr self, int i) -> long"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(pccc_decoder_combined_fi_sptr self, long max_output_buffer)
        set_max_output_buffer(pccc_decoder_combined_fi_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(pccc_decoder_combined_fi_sptr self, int i) -> long"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(pccc_decoder_combined_fi_sptr self, long min_output_buffer)
        set_min_output_buffer(pccc_decoder_combined_fi_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(pccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(pccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(pccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(pccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(pccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(pccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(pccc_decoder_combined_fi_sptr self, int which) -> float
        pc_input_buffers_full(pccc_decoder_combined_fi_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(pccc_decoder_combined_fi_sptr self, int which) -> float
        pc_input_buffers_full_avg(pccc_decoder_combined_fi_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(pccc_decoder_combined_fi_sptr self, int which) -> float
        pc_input_buffers_full_var(pccc_decoder_combined_fi_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(pccc_decoder_combined_fi_sptr self, int which) -> float
        pc_output_buffers_full(pccc_decoder_combined_fi_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(pccc_decoder_combined_fi_sptr self, int which) -> float
        pc_output_buffers_full_avg(pccc_decoder_combined_fi_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(pccc_decoder_combined_fi_sptr self, int which) -> float
        pc_output_buffers_full_var(pccc_decoder_combined_fi_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(pccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(pccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(pccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(pccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(pccc_decoder_combined_fi_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(pccc_decoder_combined_fi_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(pccc_decoder_combined_fi_sptr self)"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(pccc_decoder_combined_fi_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(pccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(pccc_decoder_combined_fi_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(pccc_decoder_combined_fi_sptr self, int priority) -> int"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(pccc_decoder_combined_fi_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(pccc_decoder_combined_fi_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(pccc_decoder_combined_fi_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(pccc_decoder_combined_fi_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(pccc_decoder_combined_fi_sptr self) -> long"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(pccc_decoder_combined_fi_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(pccc_decoder_combined_fi_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(pccc_decoder_combined_fi_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(pccc_decoder_combined_fi_sptr self, std::string name)"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(pccc_decoder_combined_fi_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(pccc_decoder_combined_fi_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(pccc_decoder_combined_fi_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(pccc_decoder_combined_fi_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_fi_sptr_message_subscribers(self, which_port)

# Register pccc_decoder_combined_fi_sptr in _trellis_swig3:
_trellis_swig3.pccc_decoder_combined_fi_sptr_swigregister(pccc_decoder_combined_fi_sptr)


pccc_decoder_combined_fi_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
pccc_decoder_combined_fi = pccc_decoder_combined_fi.make

class pccc_decoder_combined_cb(object):
    r"""Proxy of C++ gr::trellis::pccc_decoder_combined_blk< gr_complex,std::uint8_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< std::complex< float >,unsigned char >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_cb_sptr"""
        return _trellis_swig3.pccc_decoder_combined_cb_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSM1(self) -> "gr::trellis::fsm":
        r"""FSM1(pccc_decoder_combined_cb self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_cb_FSM1(self)

    def FSM2(self) -> "gr::trellis::fsm":
        r"""FSM2(pccc_decoder_combined_cb self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_cb_FSM2(self)

    def ST10(self) -> "int":
        r"""ST10(pccc_decoder_combined_cb self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_ST10(self)

    def ST1K(self) -> "int":
        r"""ST1K(pccc_decoder_combined_cb self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_ST1K(self)

    def ST20(self) -> "int":
        r"""ST20(pccc_decoder_combined_cb self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_ST20(self)

    def ST2K(self) -> "int":
        r"""ST2K(pccc_decoder_combined_cb self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_ST2K(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(pccc_decoder_combined_cb self) -> interleaver"""
        return _trellis_swig3.pccc_decoder_combined_cb_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(pccc_decoder_combined_cb self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(pccc_decoder_combined_cb self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_repetitions(self)

    def D(self) -> "int":
        r"""D(pccc_decoder_combined_cb self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_D(self)

    def TABLE(self) -> "std::vector< std::complex< float >,std::allocator< std::complex< float > > >":
        r"""TABLE(pccc_decoder_combined_cb self) -> pmt_vector_cfloat"""
        return _trellis_swig3.pccc_decoder_combined_cb_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(pccc_decoder_combined_cb self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.pccc_decoder_combined_cb_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(pccc_decoder_combined_cb self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.pccc_decoder_combined_cb_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(pccc_decoder_combined_cb self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cb_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(pccc_decoder_combined_cb self, float scaling)"""
        return _trellis_swig3.pccc_decoder_combined_cb_set_scaling(self, scaling)
    __swig_destroy__ = _trellis_swig3.delete_pccc_decoder_combined_cb

# Register pccc_decoder_combined_cb in _trellis_swig3:
_trellis_swig3.pccc_decoder_combined_cb_swigregister(pccc_decoder_combined_cb)

def pccc_decoder_combined_cb_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< std::complex< float >,unsigned char >::sptr":
    r"""pccc_decoder_combined_cb_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_cb_sptr"""
    return _trellis_swig3.pccc_decoder_combined_cb_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

class pccc_decoder_combined_cb_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::pccc_decoder_combined_blk< gr_complex,std::uint8_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(pccc_decoder_combined_cb_sptr self) -> pccc_decoder_combined_cb_sptr
        __init__(pccc_decoder_combined_cb_sptr self, pccc_decoder_combined_cb p) -> pccc_decoder_combined_cb_sptr
        """
        _trellis_swig3.pccc_decoder_combined_cb_sptr_swiginit(self, _trellis_swig3.new_pccc_decoder_combined_cb_sptr(*args))

    def __deref__(self) -> "gr::trellis::pccc_decoder_combined_blk< gr_complex,std::uint8_t > *":
        r"""__deref__(pccc_decoder_combined_cb_sptr self) -> pccc_decoder_combined_cb"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_pccc_decoder_combined_cb_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< std::complex< float >,unsigned char >::sptr":
        r"""make(pccc_decoder_combined_cb_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_cb_sptr"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSM1(self) -> "gr::trellis::fsm":
        r"""FSM1(pccc_decoder_combined_cb_sptr self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_FSM1(self)

    def FSM2(self) -> "gr::trellis::fsm":
        r"""FSM2(pccc_decoder_combined_cb_sptr self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_FSM2(self)

    def ST10(self) -> "int":
        r"""ST10(pccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_ST10(self)

    def ST1K(self) -> "int":
        r"""ST1K(pccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_ST1K(self)

    def ST20(self) -> "int":
        r"""ST20(pccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_ST20(self)

    def ST2K(self) -> "int":
        r"""ST2K(pccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_ST2K(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(pccc_decoder_combined_cb_sptr self) -> interleaver"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(pccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(pccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_repetitions(self)

    def D(self) -> "int":
        r"""D(pccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_D(self)

    def TABLE(self) -> "std::vector< std::complex< float >,std::allocator< std::complex< float > > >":
        r"""TABLE(pccc_decoder_combined_cb_sptr self) -> pmt_vector_cfloat"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(pccc_decoder_combined_cb_sptr self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(pccc_decoder_combined_cb_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(pccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(pccc_decoder_combined_cb_sptr self, float scaling)"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_set_scaling(self, scaling)

    def history(self) -> "unsigned int":
        r"""history(pccc_decoder_combined_cb_sptr self) -> unsigned int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(pccc_decoder_combined_cb_sptr self, int which, int delay)
        declare_sample_delay(pccc_decoder_combined_cb_sptr self, unsigned int delay)
        """
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(pccc_decoder_combined_cb_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(pccc_decoder_combined_cb_sptr self, int multiple)"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(pccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(pccc_decoder_combined_cb_sptr self) -> double"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(pccc_decoder_combined_cb_sptr self) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(pccc_decoder_combined_cb_sptr self) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(pccc_decoder_combined_cb_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(pccc_decoder_combined_cb_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(pccc_decoder_combined_cb_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(pccc_decoder_combined_cb_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(pccc_decoder_combined_cb_sptr self, std::string level)"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(pccc_decoder_combined_cb_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(pccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(pccc_decoder_combined_cb_sptr self, int m)"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(pccc_decoder_combined_cb_sptr self)"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(pccc_decoder_combined_cb_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(pccc_decoder_combined_cb_sptr self, int m)"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(pccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(pccc_decoder_combined_cb_sptr self, int i) -> long"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(pccc_decoder_combined_cb_sptr self, long max_output_buffer)
        set_max_output_buffer(pccc_decoder_combined_cb_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(pccc_decoder_combined_cb_sptr self, int i) -> long"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(pccc_decoder_combined_cb_sptr self, long min_output_buffer)
        set_min_output_buffer(pccc_decoder_combined_cb_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(pccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(pccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(pccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(pccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(pccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(pccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(pccc_decoder_combined_cb_sptr self, int which) -> float
        pc_input_buffers_full(pccc_decoder_combined_cb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(pccc_decoder_combined_cb_sptr self, int which) -> float
        pc_input_buffers_full_avg(pccc_decoder_combined_cb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(pccc_decoder_combined_cb_sptr self, int which) -> float
        pc_input_buffers_full_var(pccc_decoder_combined_cb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(pccc_decoder_combined_cb_sptr self, int which) -> float
        pc_output_buffers_full(pccc_decoder_combined_cb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(pccc_decoder_combined_cb_sptr self, int which) -> float
        pc_output_buffers_full_avg(pccc_decoder_combined_cb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(pccc_decoder_combined_cb_sptr self, int which) -> float
        pc_output_buffers_full_var(pccc_decoder_combined_cb_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(pccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(pccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(pccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(pccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(pccc_decoder_combined_cb_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(pccc_decoder_combined_cb_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(pccc_decoder_combined_cb_sptr self)"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(pccc_decoder_combined_cb_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(pccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(pccc_decoder_combined_cb_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(pccc_decoder_combined_cb_sptr self, int priority) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(pccc_decoder_combined_cb_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(pccc_decoder_combined_cb_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(pccc_decoder_combined_cb_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(pccc_decoder_combined_cb_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(pccc_decoder_combined_cb_sptr self) -> long"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(pccc_decoder_combined_cb_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(pccc_decoder_combined_cb_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(pccc_decoder_combined_cb_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(pccc_decoder_combined_cb_sptr self, std::string name)"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(pccc_decoder_combined_cb_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(pccc_decoder_combined_cb_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(pccc_decoder_combined_cb_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(pccc_decoder_combined_cb_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_cb_sptr_message_subscribers(self, which_port)

# Register pccc_decoder_combined_cb_sptr in _trellis_swig3:
_trellis_swig3.pccc_decoder_combined_cb_sptr_swigregister(pccc_decoder_combined_cb_sptr)


pccc_decoder_combined_cb_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
pccc_decoder_combined_cb = pccc_decoder_combined_cb.make

class pccc_decoder_combined_cs(object):
    r"""Proxy of C++ gr::trellis::pccc_decoder_combined_blk< gr_complex,std::int16_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< std::complex< float >,short >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_cs_sptr"""
        return _trellis_swig3.pccc_decoder_combined_cs_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSM1(self) -> "gr::trellis::fsm":
        r"""FSM1(pccc_decoder_combined_cs self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_cs_FSM1(self)

    def FSM2(self) -> "gr::trellis::fsm":
        r"""FSM2(pccc_decoder_combined_cs self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_cs_FSM2(self)

    def ST10(self) -> "int":
        r"""ST10(pccc_decoder_combined_cs self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_ST10(self)

    def ST1K(self) -> "int":
        r"""ST1K(pccc_decoder_combined_cs self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_ST1K(self)

    def ST20(self) -> "int":
        r"""ST20(pccc_decoder_combined_cs self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_ST20(self)

    def ST2K(self) -> "int":
        r"""ST2K(pccc_decoder_combined_cs self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_ST2K(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(pccc_decoder_combined_cs self) -> interleaver"""
        return _trellis_swig3.pccc_decoder_combined_cs_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(pccc_decoder_combined_cs self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(pccc_decoder_combined_cs self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_repetitions(self)

    def D(self) -> "int":
        r"""D(pccc_decoder_combined_cs self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_D(self)

    def TABLE(self) -> "std::vector< std::complex< float >,std::allocator< std::complex< float > > >":
        r"""TABLE(pccc_decoder_combined_cs self) -> pmt_vector_cfloat"""
        return _trellis_swig3.pccc_decoder_combined_cs_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(pccc_decoder_combined_cs self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.pccc_decoder_combined_cs_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(pccc_decoder_combined_cs self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.pccc_decoder_combined_cs_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(pccc_decoder_combined_cs self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cs_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(pccc_decoder_combined_cs self, float scaling)"""
        return _trellis_swig3.pccc_decoder_combined_cs_set_scaling(self, scaling)
    __swig_destroy__ = _trellis_swig3.delete_pccc_decoder_combined_cs

# Register pccc_decoder_combined_cs in _trellis_swig3:
_trellis_swig3.pccc_decoder_combined_cs_swigregister(pccc_decoder_combined_cs)

def pccc_decoder_combined_cs_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< std::complex< float >,short >::sptr":
    r"""pccc_decoder_combined_cs_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_cs_sptr"""
    return _trellis_swig3.pccc_decoder_combined_cs_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

class pccc_decoder_combined_cs_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::pccc_decoder_combined_blk< gr_complex,std::int16_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(pccc_decoder_combined_cs_sptr self) -> pccc_decoder_combined_cs_sptr
        __init__(pccc_decoder_combined_cs_sptr self, pccc_decoder_combined_cs p) -> pccc_decoder_combined_cs_sptr
        """
        _trellis_swig3.pccc_decoder_combined_cs_sptr_swiginit(self, _trellis_swig3.new_pccc_decoder_combined_cs_sptr(*args))

    def __deref__(self) -> "gr::trellis::pccc_decoder_combined_blk< gr_complex,std::int16_t > *":
        r"""__deref__(pccc_decoder_combined_cs_sptr self) -> pccc_decoder_combined_cs"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_pccc_decoder_combined_cs_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< std::complex< float >,short >::sptr":
        r"""make(pccc_decoder_combined_cs_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_cs_sptr"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSM1(self) -> "gr::trellis::fsm":
        r"""FSM1(pccc_decoder_combined_cs_sptr self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_FSM1(self)

    def FSM2(self) -> "gr::trellis::fsm":
        r"""FSM2(pccc_decoder_combined_cs_sptr self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_FSM2(self)

    def ST10(self) -> "int":
        r"""ST10(pccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_ST10(self)

    def ST1K(self) -> "int":
        r"""ST1K(pccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_ST1K(self)

    def ST20(self) -> "int":
        r"""ST20(pccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_ST20(self)

    def ST2K(self) -> "int":
        r"""ST2K(pccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_ST2K(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(pccc_decoder_combined_cs_sptr self) -> interleaver"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(pccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(pccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_repetitions(self)

    def D(self) -> "int":
        r"""D(pccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_D(self)

    def TABLE(self) -> "std::vector< std::complex< float >,std::allocator< std::complex< float > > >":
        r"""TABLE(pccc_decoder_combined_cs_sptr self) -> pmt_vector_cfloat"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(pccc_decoder_combined_cs_sptr self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(pccc_decoder_combined_cs_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(pccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(pccc_decoder_combined_cs_sptr self, float scaling)"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_set_scaling(self, scaling)

    def history(self) -> "unsigned int":
        r"""history(pccc_decoder_combined_cs_sptr self) -> unsigned int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(pccc_decoder_combined_cs_sptr self, int which, int delay)
        declare_sample_delay(pccc_decoder_combined_cs_sptr self, unsigned int delay)
        """
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(pccc_decoder_combined_cs_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(pccc_decoder_combined_cs_sptr self, int multiple)"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(pccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(pccc_decoder_combined_cs_sptr self) -> double"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(pccc_decoder_combined_cs_sptr self) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(pccc_decoder_combined_cs_sptr self) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(pccc_decoder_combined_cs_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(pccc_decoder_combined_cs_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(pccc_decoder_combined_cs_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(pccc_decoder_combined_cs_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(pccc_decoder_combined_cs_sptr self, std::string level)"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(pccc_decoder_combined_cs_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(pccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(pccc_decoder_combined_cs_sptr self, int m)"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(pccc_decoder_combined_cs_sptr self)"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(pccc_decoder_combined_cs_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(pccc_decoder_combined_cs_sptr self, int m)"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(pccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(pccc_decoder_combined_cs_sptr self, int i) -> long"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(pccc_decoder_combined_cs_sptr self, long max_output_buffer)
        set_max_output_buffer(pccc_decoder_combined_cs_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(pccc_decoder_combined_cs_sptr self, int i) -> long"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(pccc_decoder_combined_cs_sptr self, long min_output_buffer)
        set_min_output_buffer(pccc_decoder_combined_cs_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(pccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(pccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(pccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(pccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(pccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(pccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(pccc_decoder_combined_cs_sptr self, int which) -> float
        pc_input_buffers_full(pccc_decoder_combined_cs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(pccc_decoder_combined_cs_sptr self, int which) -> float
        pc_input_buffers_full_avg(pccc_decoder_combined_cs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(pccc_decoder_combined_cs_sptr self, int which) -> float
        pc_input_buffers_full_var(pccc_decoder_combined_cs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(pccc_decoder_combined_cs_sptr self, int which) -> float
        pc_output_buffers_full(pccc_decoder_combined_cs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(pccc_decoder_combined_cs_sptr self, int which) -> float
        pc_output_buffers_full_avg(pccc_decoder_combined_cs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(pccc_decoder_combined_cs_sptr self, int which) -> float
        pc_output_buffers_full_var(pccc_decoder_combined_cs_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(pccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(pccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(pccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(pccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(pccc_decoder_combined_cs_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(pccc_decoder_combined_cs_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(pccc_decoder_combined_cs_sptr self)"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(pccc_decoder_combined_cs_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(pccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(pccc_decoder_combined_cs_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(pccc_decoder_combined_cs_sptr self, int priority) -> int"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(pccc_decoder_combined_cs_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(pccc_decoder_combined_cs_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(pccc_decoder_combined_cs_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(pccc_decoder_combined_cs_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(pccc_decoder_combined_cs_sptr self) -> long"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(pccc_decoder_combined_cs_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(pccc_decoder_combined_cs_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(pccc_decoder_combined_cs_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(pccc_decoder_combined_cs_sptr self, std::string name)"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(pccc_decoder_combined_cs_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(pccc_decoder_combined_cs_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(pccc_decoder_combined_cs_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(pccc_decoder_combined_cs_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_cs_sptr_message_subscribers(self, which_port)

# Register pccc_decoder_combined_cs_sptr in _trellis_swig3:
_trellis_swig3.pccc_decoder_combined_cs_sptr_swigregister(pccc_decoder_combined_cs_sptr)


pccc_decoder_combined_cs_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
pccc_decoder_combined_cs = pccc_decoder_combined_cs.make

class pccc_decoder_combined_ci(object):
    r"""Proxy of C++ gr::trellis::pccc_decoder_combined_blk< gr_complex,std::int32_t > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< std::complex< float >,int >::sptr":
        r"""make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_ci_sptr"""
        return _trellis_swig3.pccc_decoder_combined_ci_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSM1(self) -> "gr::trellis::fsm":
        r"""FSM1(pccc_decoder_combined_ci self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_ci_FSM1(self)

    def FSM2(self) -> "gr::trellis::fsm":
        r"""FSM2(pccc_decoder_combined_ci self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_ci_FSM2(self)

    def ST10(self) -> "int":
        r"""ST10(pccc_decoder_combined_ci self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_ST10(self)

    def ST1K(self) -> "int":
        r"""ST1K(pccc_decoder_combined_ci self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_ST1K(self)

    def ST20(self) -> "int":
        r"""ST20(pccc_decoder_combined_ci self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_ST20(self)

    def ST2K(self) -> "int":
        r"""ST2K(pccc_decoder_combined_ci self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_ST2K(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(pccc_decoder_combined_ci self) -> interleaver"""
        return _trellis_swig3.pccc_decoder_combined_ci_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(pccc_decoder_combined_ci self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(pccc_decoder_combined_ci self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_repetitions(self)

    def D(self) -> "int":
        r"""D(pccc_decoder_combined_ci self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_D(self)

    def TABLE(self) -> "std::vector< std::complex< float >,std::allocator< std::complex< float > > >":
        r"""TABLE(pccc_decoder_combined_ci self) -> pmt_vector_cfloat"""
        return _trellis_swig3.pccc_decoder_combined_ci_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(pccc_decoder_combined_ci self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.pccc_decoder_combined_ci_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(pccc_decoder_combined_ci self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.pccc_decoder_combined_ci_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(pccc_decoder_combined_ci self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_ci_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(pccc_decoder_combined_ci self, float scaling)"""
        return _trellis_swig3.pccc_decoder_combined_ci_set_scaling(self, scaling)
    __swig_destroy__ = _trellis_swig3.delete_pccc_decoder_combined_ci

# Register pccc_decoder_combined_ci in _trellis_swig3:
_trellis_swig3.pccc_decoder_combined_ci_swigregister(pccc_decoder_combined_ci)

def pccc_decoder_combined_ci_make(FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< std::complex< float >,int >::sptr":
    r"""pccc_decoder_combined_ci_make(fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_ci_sptr"""
    return _trellis_swig3.pccc_decoder_combined_ci_make(FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

class pccc_decoder_combined_ci_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::trellis::pccc_decoder_combined_blk< gr_complex,std::int32_t > > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(pccc_decoder_combined_ci_sptr self) -> pccc_decoder_combined_ci_sptr
        __init__(pccc_decoder_combined_ci_sptr self, pccc_decoder_combined_ci p) -> pccc_decoder_combined_ci_sptr
        """
        _trellis_swig3.pccc_decoder_combined_ci_sptr_swiginit(self, _trellis_swig3.new_pccc_decoder_combined_ci_sptr(*args))

    def __deref__(self) -> "gr::trellis::pccc_decoder_combined_blk< gr_complex,std::int32_t > *":
        r"""__deref__(pccc_decoder_combined_ci_sptr self) -> pccc_decoder_combined_ci"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr___deref__(self)
    __swig_destroy__ = _trellis_swig3.delete_pccc_decoder_combined_ci_sptr

    def make(self, FSMo: "fsm", STo0: "int", SToK: "int", FSMi: "fsm", STi0: "int", STiK: "int", INTERLEAVER: "interleaver", blocklength: "int", repetitions: "int", SISO_TYPE: "gr::trellis::siso_type_t", D: "int", TABLE: "pmt_vector_cfloat", METRIC_TYPE: "gr::digital::trellis_metric_type_t", scaling: "float") -> "gr::trellis::pccc_decoder_combined_blk< std::complex< float >,int >::sptr":
        r"""make(pccc_decoder_combined_ci_sptr self, fsm FSMo, int STo0, int SToK, fsm FSMi, int STi0, int STiK, interleaver INTERLEAVER, int blocklength, int repetitions, gr::trellis::siso_type_t SISO_TYPE, int D, pmt_vector_cfloat TABLE, gr::digital::trellis_metric_type_t METRIC_TYPE, float scaling) -> pccc_decoder_combined_ci_sptr"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_make(self, FSMo, STo0, SToK, FSMi, STi0, STiK, INTERLEAVER, blocklength, repetitions, SISO_TYPE, D, TABLE, METRIC_TYPE, scaling)

    def FSM1(self) -> "gr::trellis::fsm":
        r"""FSM1(pccc_decoder_combined_ci_sptr self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_FSM1(self)

    def FSM2(self) -> "gr::trellis::fsm":
        r"""FSM2(pccc_decoder_combined_ci_sptr self) -> fsm"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_FSM2(self)

    def ST10(self) -> "int":
        r"""ST10(pccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_ST10(self)

    def ST1K(self) -> "int":
        r"""ST1K(pccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_ST1K(self)

    def ST20(self) -> "int":
        r"""ST20(pccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_ST20(self)

    def ST2K(self) -> "int":
        r"""ST2K(pccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_ST2K(self)

    def INTERLEAVER(self) -> "gr::trellis::interleaver":
        r"""INTERLEAVER(pccc_decoder_combined_ci_sptr self) -> interleaver"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_INTERLEAVER(self)

    def blocklength(self) -> "int":
        r"""blocklength(pccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_blocklength(self)

    def repetitions(self) -> "int":
        r"""repetitions(pccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_repetitions(self)

    def D(self) -> "int":
        r"""D(pccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_D(self)

    def TABLE(self) -> "std::vector< std::complex< float >,std::allocator< std::complex< float > > >":
        r"""TABLE(pccc_decoder_combined_ci_sptr self) -> pmt_vector_cfloat"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_TABLE(self)

    def METRIC_TYPE(self) -> "gr::digital::trellis_metric_type_t":
        r"""METRIC_TYPE(pccc_decoder_combined_ci_sptr self) -> gr::digital::trellis_metric_type_t"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_METRIC_TYPE(self)

    def SISO_TYPE(self) -> "gr::trellis::siso_type_t":
        r"""SISO_TYPE(pccc_decoder_combined_ci_sptr self) -> gr::trellis::siso_type_t"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_SISO_TYPE(self)

    def scaling(self) -> "float":
        r"""scaling(pccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_scaling(self)

    def set_scaling(self, scaling: "float") -> "void":
        r"""set_scaling(pccc_decoder_combined_ci_sptr self, float scaling)"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_set_scaling(self, scaling)

    def history(self) -> "unsigned int":
        r"""history(pccc_decoder_combined_ci_sptr self) -> unsigned int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(pccc_decoder_combined_ci_sptr self, int which, int delay)
        declare_sample_delay(pccc_decoder_combined_ci_sptr self, unsigned int delay)
        """
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(pccc_decoder_combined_ci_sptr self, int which) -> unsigned int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(pccc_decoder_combined_ci_sptr self, int multiple)"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(pccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(pccc_decoder_combined_ci_sptr self) -> double"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(pccc_decoder_combined_ci_sptr self) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(pccc_decoder_combined_ci_sptr self) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(pccc_decoder_combined_ci_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(pccc_decoder_combined_ci_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(pccc_decoder_combined_ci_sptr self, unsigned int which_input) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(pccc_decoder_combined_ci_sptr self, unsigned int which_output) -> uint64_t"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(pccc_decoder_combined_ci_sptr self, std::string level)"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(pccc_decoder_combined_ci_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(pccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(pccc_decoder_combined_ci_sptr self, int m)"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(pccc_decoder_combined_ci_sptr self)"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(pccc_decoder_combined_ci_sptr self) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(pccc_decoder_combined_ci_sptr self, int m)"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(pccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(pccc_decoder_combined_ci_sptr self, int i) -> long"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(pccc_decoder_combined_ci_sptr self, long max_output_buffer)
        set_max_output_buffer(pccc_decoder_combined_ci_sptr self, int port, long max_output_buffer)
        """
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(pccc_decoder_combined_ci_sptr self, int i) -> long"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(pccc_decoder_combined_ci_sptr self, long min_output_buffer)
        set_min_output_buffer(pccc_decoder_combined_ci_sptr self, int port, long min_output_buffer)
        """
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(pccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(pccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(pccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(pccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(pccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(pccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(pccc_decoder_combined_ci_sptr self, int which) -> float
        pc_input_buffers_full(pccc_decoder_combined_ci_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(pccc_decoder_combined_ci_sptr self, int which) -> float
        pc_input_buffers_full_avg(pccc_decoder_combined_ci_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(pccc_decoder_combined_ci_sptr self, int which) -> float
        pc_input_buffers_full_var(pccc_decoder_combined_ci_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(pccc_decoder_combined_ci_sptr self, int which) -> float
        pc_output_buffers_full(pccc_decoder_combined_ci_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(pccc_decoder_combined_ci_sptr self, int which) -> float
        pc_output_buffers_full_avg(pccc_decoder_combined_ci_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(pccc_decoder_combined_ci_sptr self, int which) -> float
        pc_output_buffers_full_var(pccc_decoder_combined_ci_sptr self) -> pmt_vector_float
        """
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(pccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(pccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(pccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(pccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(pccc_decoder_combined_ci_sptr self) -> float"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(pccc_decoder_combined_ci_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(pccc_decoder_combined_ci_sptr self)"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(pccc_decoder_combined_ci_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(pccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(pccc_decoder_combined_ci_sptr self) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(pccc_decoder_combined_ci_sptr self, int priority) -> int"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(pccc_decoder_combined_ci_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(pccc_decoder_combined_ci_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(pccc_decoder_combined_ci_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(pccc_decoder_combined_ci_sptr self) -> io_signature_sptr"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(pccc_decoder_combined_ci_sptr self) -> long"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(pccc_decoder_combined_ci_sptr self) -> basic_block_sptr"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(pccc_decoder_combined_ci_sptr self, int ninputs, int noutputs) -> bool"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(pccc_decoder_combined_ci_sptr self) -> std::string"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(pccc_decoder_combined_ci_sptr self, std::string name)"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(pccc_decoder_combined_ci_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(pccc_decoder_combined_ci_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(pccc_decoder_combined_ci_sptr self) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(pccc_decoder_combined_ci_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _trellis_swig3.pccc_decoder_combined_ci_sptr_message_subscribers(self, which_port)

# Register pccc_decoder_combined_ci_sptr in _trellis_swig3:
_trellis_swig3.pccc_decoder_combined_ci_sptr_swigregister(pccc_decoder_combined_ci_sptr)


pccc_decoder_combined_ci_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
pccc_decoder_combined_ci = pccc_decoder_combined_ci.make



